@@ -16,15 +16,6 @@
 
 set -e
 
-$SHELL clean.sh
-
-copy_setports ns2/named.conf.in ns2/named.conf
-copy_setports ns4/named.conf.in ns4/named.conf
-copy_setports ns5/named.conf.in ns5/named.conf
-copy_setports ns6/named.conf.in ns6/named.conf
-copy_setports ns7/named.conf.in ns7/named.conf
-copy_setports ns9/named.conf.in ns9/named.conf
-
 # Setup zones
 (
   cd ns9
@@ -38,3 +29,7 @@ copy_setports ns9/named.conf.in ns9/named.conf
   cd ns2
   $SHELL setup.sh
 )
+(
+  cd ns1
+  $SHELL setup.sh
+)
