@@ -135,10 +135,10 @@ dyndb_init(isc_mem_t *mctx, const char *name, const char *parameters,
 cleanup:
 	isc_mem_free(mctx, s);
 	if (argv != NULL) {
-		isc_mem_put(mctx, argv, argc * sizeof(*argv));
+		isc_mem_cput(mctx, argv, argc, sizeof(*argv));
 	}
 
-	return (result);
+	return result;
 }
 
 /*
@@ -160,5 +160,5 @@ int
 dyndb_version(unsigned int *flags) {
 	UNUSED(flags);
 
-	return (DNS_DYNDB_VERSION);
+	return DNS_DYNDB_VERSION;
 }
