@@ -50,11 +50,9 @@ usage(void) {
 	fprintf(stderr, "\t--have-json-c\n");
 	fprintf(stderr, "\t--have-libxml2\n");
 	fprintf(stderr, "\t--have-openssl-cipher-suites\n");
-	fprintf(stderr, "\t--ipv6only=no\n");
 	fprintf(stderr, "\t--md5\n");
 	fprintf(stderr, "\t--rsasha1\n");
 	fprintf(stderr, "\t--tsan\n");
-	fprintf(stderr, "\t--with-dlz-filesystem\n");
 	fprintf(stderr, "\t--with-libidn2\n");
 	fprintf(stderr, "\t--with-lmdb\n");
 	fprintf(stderr, "\t--with-libnghttp2\n");
@@ -218,25 +216,6 @@ main(int argc, char **argv) {
 		return answer;
 	}
 
-	if (strcmp(argv[1], "--ipv6only=no") == 0) {
-#if defined(IPPROTO_IPV6) && defined(IPV6_V6ONLY)
-		int s;
-		int n = -1;
-		int v6only = -1;
-		socklen_t len = sizeof(v6only);
-
-		s = socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP);
-		if (s >= 0) {
-			n = getsockopt(s, IPPROTO_IPV6, IPV6_V6ONLY,
-				       (void *)&v6only, &len);
-			close(s);
-		}
-		return (n == 0 && v6only == 0) ? 0 : 1;
-#else  /* defined(IPPROTO_IPV6) && defined(IPV6_V6ONLY) */
-		return 1;
-#endif /* defined(IPPROTO_IPV6) && defined(IPV6_V6ONLY) */
-	}
-
 	if (strcasecmp(argv[1], "--rsasha1") == 0) {
 		int answer;
 		isc_mem_t *mctx = NULL;
@@ -248,14 +227,6 @@ main(int argc, char **argv) {
 		return answer;
 	}
 
-	if (strcmp(argv[1], "--with-dlz-filesystem") == 0) {
-#ifdef DLZ_FILESYSTEM
-		return 0;
-#else  /* ifdef DLZ_FILESYSTEM */
-		return 1;
-#endif /* ifdef DLZ_FILESYSTEM */
-	}
-
 	if (strcmp(argv[1], "--with-libidn2") == 0) {
 #ifdef HAVE_LIBIDN2
 		return 0;
