@@ -11,18 +11,22 @@
 
 import pytest
 
+# isctest.asyncserver requires dnspython >= 2.0.0
+pytest.importorskip("dns", minversion="2.0.0")
+
 pytestmark = pytest.mark.extra_artifacts(
     [
         "dig.out.*",
         "statschannel.out.*",
         "ans*/ans.run",
-        "ans*/query.log",
         "ns*/trusted.conf",
         "ns1/K*",
         "ns1/dsset-*",
         "ns1/root.db",
         "ns1/root.db.signed",
+        "ns2/named-tls.conf",
         "ns3/trusted.conf",
+        "ns4/named-tls.conf",
         "ns9/named_dump.db",
     ]
 )
