@@ -365,11 +365,11 @@ openpgpkey		OPENPGPKEY	( AQMFD5raczCJHViKtLYhWGz8hMY
 				sENW91IOW4vqudngPZsY3GvQ/xVA8/7pyFj6b7Esg
 				a60zyGW6LFe9r8n6paHrlG5ojqf0BaqHT+8= )
 
-;type	62
+; type 62
 csync01			CSYNC	0 0 A NS AAAA
 csync02			CSYNC	0 0
 
-;type	63
+; type 63
 zonemd01		ZONEMD	2019020700 1 1 (
                                 C220B8A6ED5728A971902F7E3D4FD93A
                                 DEEA88B0453C2E8E8C863D465AB06CF3
@@ -381,8 +381,24 @@ zonemd02		ZONEMD	2019020700 1 2 (
                                 4E114D884E66F176EAB121CB02DB7D65
                                 2E0CC4827E7A3204F166B47E5613FD27
 				)
+; type 64
+svcb0			SVCB	0 example.net.
+svcb1			SVCB	1 . port=60
 
-; type 64 -- 98 (unassigned)
+; type 65
+https0			HTTPS	0 example.net.
+https1			HTTPS	1 . port=60
+
+; type 66
+dsync01			DSYNC	CDS NOTIFY 53 .
+
+; type 67
+hhit			HHIT	abcd
+
+; type 68
+brid			BRID	abcd
+
+; type 69 -- 98 (unassigned)
 
 ; type 99
 spf01			SPF	"v=spf1 -all"
@@ -471,8 +487,8 @@ doa01			DOA	( 1234567890 1234567890 1 "image/gif"
 doa02			DOA	0 1 2 "" aHR0cHM6Ly93d3cuaXNjLm9yZy8=
 
 ; type 260
-amtrelay01		AMTRELAY 0 0 0
-amtrelay02		AMTRELAY 0 1 0
+amtrelay01		AMTRELAY 0 0 0 .
+amtrelay02		AMTRELAY 0 1 0 .
 amtrelay03		AMTRELAY 0 0 1 0.0.0.0
 amtrelay04		AMTRELAY 0 0 2 ::
 amtrelay05		AMTRELAY 0 0 3 example.net.
@@ -503,12 +519,6 @@ dlv			DLV	30795 1 1 (
 
 ; type 65280-65534 (private use)
 
-https0			HTTPS	0 example.net.
-https1			HTTPS	1 . port=60
-
-svcb0			SVCB	0 example.net.
-svcb1			SVCB	1 . port=60
-
 ; keydata (internal type used for managed keys)
 keydata			TYPE65533	\# 0
 keydata			TYPE65533	\# 6 010203040506
