@@ -15,8 +15,4 @@ set -e
 
 . ../conf.sh
 
-$SHELL clean.sh
-
 $SHELL ${TOP_SRCDIR}/bin/tests/system/genzone.sh 1 >ns1/example.db
-
-copy_setports ns1/named.conf.in ns1/named.conf
