@@ -38,15 +38,7 @@ mkdir ns3/removedkeys
 touch ns4/trusted.conf
 cp ns4/noixfr.db.in ns4/noixfr.db
 
-copy_setports ns1/named.conf.in ns1/named.conf
-copy_setports ns2/named.conf.in ns2/named.conf
-copy_setports ns3/named.conf.in ns3/named.conf
 cp ns3/delayedkeys.conf.1 ns3/delayedkeys.conf
-copy_setports ns4/named.conf.in ns4/named.conf
-copy_setports ns5/named.conf.pre ns5/named.conf
-copy_setports ns6/named.conf.in ns6/named.conf
-copy_setports ns7/named.conf.in ns7/named.conf
-copy_setports ns8/named.conf.in ns8/named.conf
 
 (
   cd ns3
