@@ -11,10 +11,11 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
+from dataclasses import dataclass
 from pathlib import Path
 from typing import Any, Dict, Optional, Union
 
-import pytest
+import jinja2
 
 from .log import debug
 from .vars import ALL
@@ -32,29 +33,13 @@ class TemplateEngine:
         to the environment variables set by the pytest runner).
         """
         self.directory = Path(directory)
-        self._j2env = None
         self.env_vars = dict(env_vars)
-
-    @property
-    def j2env(self):
-        """
-        Jinja2 engine that is initialized when first requested. In case the
-        jinja2 package in unavailable, the current test will be skipped.
-        """
-        if self._j2env is None:
-            try:
-                import jinja2  # pylint: disable=import-outside-toplevel
-            except ImportError:
-                pytest.skip("jinja2 not found")
-
-            loader = jinja2.FileSystemLoader(str(self.directory))
-            return jinja2.Environment(
-                loader=loader,
-                undefined=jinja2.StrictUndefined,
-                variable_start_string="@",
-                variable_end_string="@",
-            )
-        return self._j2env
+        self.j2env = jinja2.Environment(
+            loader=jinja2.FileSystemLoader(str(self.directory)),
+            undefined=jinja2.StrictUndefined,
+            variable_start_string="@",
+            variable_end_string="@",
+        )
 
     def render(
         self,
@@ -84,14 +69,35 @@ class TemplateEngine:
         stream = self.j2env.get_template(template).stream(data)
         stream.dump(output, encoding="utf-8")
 
-    def render_auto(self):
+    def render_auto(self, data: Optional[Dict[str, Any]] = None):
         """
-        Render all *.j2 templates with default values and write the output to
-        files without the .j2 extensions.
+        Render all *.j2 templates with default (and optionally the provided)
+        values and write the output to files without the .j2 extensions.
         """
         templates = [
             str(filepath.relative_to(self.directory))
             for filepath in self.directory.rglob("*.j2")
         ]
         for template in templates:
-            self.render(template[:-3])
+            self.render(template[:-3], data)
+
+
+@dataclass
+class Nameserver:
+    name: str
+    ip: str
+
+
+@dataclass
+class Zone:
+    name: str
+    filename: str
+    ns: Nameserver
+    type: str = "primary"
+
+
+@dataclass
+class TrustAnchor:
+    domain: str
+    type: str
+    contents: str
