@@ -11,10 +11,9 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-SYSTEMTESTTOP=..
-. $SYSTEMTESTTOP/conf.sh
-THISDIR=$(pwd)
-CONFDIR="ns1"
+set -e
+
+. ../conf.sh
 
 # Test given condition.  If true, test again after a second.  Used for testing
 # filesystem-dependent conditions in order to prevent false negatives caused by
@@ -32,14 +31,12 @@ test_with_retry() {
 status=0
 n=0
 
-echo_i "testing log file validity (named -g + only plain files allowed)"
-
 # First run with a known good config.
 n=$((n + 1))
 echo_i "testing log file validity (only plain files allowed) ($n)"
 ret=0
 cat /dev/null >ns1/named_log
-copy_setports ns1/named.plainconf.in ns1/named.conf
+cp ns1/named.plainlog.conf ns1/named.conf
 nextpart ns1/named.run >/dev/null
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
 wait_for_log 5 "reloading configuration succeeded" ns1/named.run || ret=1
@@ -51,7 +48,7 @@ n=$((n + 1))
 echo_i "testing directory as log file ($n)"
 ret=0
 nextpart ns1/named.run >/dev/null
-copy_setports ns1/named.dirconf.in ns1/named.conf
+cp ns1/named.dir.conf ns1/named.conf
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
 wait_for_log 5 "reloading configuration failed: invalid file" ns1/named.run || ret=1
 if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -64,7 +61,7 @@ ret=0
 nextpart ns1/named.run >/dev/null
 rm -f ns1/named_pipe
 if mkfifo ns1/named_pipe >/dev/null 2>&1; then
-  copy_setports ns1/named.pipeconf.in ns1/named.conf
+  cp ns1/named.pipe.conf ns1/named.conf
   rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
   wait_for_log 5 "reloading configuration failed: invalid file" ns1/named.run || ret=1
   if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -81,7 +78,7 @@ rm -f ns1/named_log ns1/named_sym
 touch ns1/named_log
 if ln -s $(pwd)/ns1/named_log $(pwd)/ns1/named_sym >/dev/null 2>&1; then
   nextpart ns1/named.run >/dev/null
-  copy_setports ns1/named.symconf.in ns1/named.conf
+  cp ns1/named.sym.conf ns1/named.conf
   rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
   wait_for_log 5 "reloading configuration succeeded" ns1/named.run || ret=1
   if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -91,8 +88,8 @@ else
 fi
 
 echo_i "repeat previous tests without named -g"
-copy_setports ns1/named.plain.in ns1/named.conf
-$PERL ../stop.pl --use-rndc --port ${CONTROLPORT} logfileconfig ns1
+cp ns1/named.plain.conf ns1/named.conf
+stop_server --use-rndc --port ${CONTROLPORT} ns1
 cp named1.args ns1/named.args
 start_server --noclean --restart --port ${PORT} ns1
 
@@ -100,7 +97,7 @@ n=$((n + 1))
 echo_i "testing log file validity (only plain files allowed) ($n)"
 ret=0
 cat /dev/null >ns1/named_log
-copy_setports ns1/named.plainconf.in ns1/named.conf
+cp ns1/named.plainlog.conf ns1/named.conf
 nextpart ns1/named.run >/dev/null
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
 wait_for_log 5 "reloading configuration succeeded" ns1/named.run || ret=1
@@ -112,7 +109,7 @@ n=$((n + 1))
 echo_i "testing directory as log file ($n)"
 ret=0
 nextpart ns1/named.run >/dev/null
-copy_setports ns1/named.dirconf.in ns1/named.conf
+cp ns1/named.dir.conf ns1/named.conf
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
 wait_for_log 5 "reloading configuration failed: invalid file" ns1/named.run || ret=1
 if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -125,7 +122,7 @@ ret=0
 nextpart ns1/named.run >/dev/null
 rm -f ns1/named_pipe
 if mkfifo ns1/named_pipe >/dev/null 2>&1; then
-  copy_setports ns1/named.pipeconf.in ns1/named.conf
+  cp ns1/named.pipe.conf ns1/named.conf
   rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
   wait_for_log 5 "reloading configuration failed: invalid file" ns1/named.run || ret=1
   if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -142,7 +139,7 @@ rm -f ns1/named_log ns1/named_sym
 touch ns1/named_log
 if ln -s $(pwd)/ns1/named_log $(pwd)/ns1/named_sym >/dev/null 2>&1; then
   nextpart ns1/named.run >/dev/null
-  copy_setports ns1/named.symconf.in ns1/named.conf
+  cp ns1/named.sym.conf ns1/named.conf
   rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
   wait_for_log 5 "reloading configuration succeeded" ns1/named.run || ret=1
   if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -155,7 +152,7 @@ echo_i "testing logging functionality"
 n=$((n + 1))
 ret=0
 echo_i "testing iso8601 timestamp ($n)"
-copy_setports ns1/named.iso8601.in ns1/named.conf
+cp ns1/named.iso8601.conf ns1/named.conf
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
 grep '^....-..-..T..:..:..\.... ' ns1/named_iso8601 >/dev/null || ret=1
 if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -164,7 +161,7 @@ status=$((status + ret))
 n=$((n + 1))
 echo_i "testing iso8601-utc timestamp ($n)"
 ret=0
-copy_setports ns1/named.iso8601-utc.in ns1/named.conf
+cp ns1/named.iso8601-utc.conf ns1/named.conf
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
 grep '^....-..-..T..:..:..\....Z' ns1/named_iso8601_utc >/dev/null || ret=1
 if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
@@ -173,7 +170,7 @@ status=$((status + ret))
 n=$((n + 1))
 echo_i "testing explicit versions ($n)"
 ret=0
-copy_setports ns1/named.versconf.in ns1/named.conf
+cp ns1/named.vers.conf ns1/named.conf
 # a seconds since epoch version number
 touch ns1/named_vers.1480039317
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
@@ -191,7 +188,7 @@ status=$((status + ret))
 n=$((n + 1))
 echo_i "testing timestamped versions ($n)"
 ret=0
-copy_setports ns1/named.tsconf.in ns1/named.conf
+cp ns1/named.ts.conf ns1/named.conf
 # a seconds since epoch version number
 touch ns1/named_ts.1480039317
 # a timestamp version number
@@ -213,10 +210,62 @@ retry_quiet 5 _found2 || ret=1
 if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
 status=$((status + ret))
 
+n=$((n + 1))
+echo_i "testing incremented versions ($n)"
+ret=0
+cp ns1/named.inc.conf ns1/named.conf
+try=0
+while test $try -lt 12; do
+  touch ns1/named_inc.$try
+  try=$((try + 1))
+done
+rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
+_found2() (
+  $DIG version.bind txt ch @10.53.0.1 -p ${PORT} >dig.out.test$n || return 1
+  grep "status: NOERROR" dig.out.test$n >/dev/null || return 1
+
+  try=1
+  while test $try -lt 12; do
+    [ -f ns1/named_inc.$try ] && return 1
+    try=$((try + 1))
+  done
+  set -- ns1/named_inc.*
+  [ "$#" -eq 1 ] || return 1
+)
+retry_quiet 5 _found2 || ret=1
+if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
+status=$((status + ret))
+
+n=$((n + 1))
+echo_i "testing absolute file path versions ($n)"
+ret=0
+cp ns1/named.abspath.conf ns1/named.conf
+try=0
+while test $try -lt 12; do
+  touch $TMPDIR/example.log.$try
+  try=$((try + 1))
+done
+rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
+_found2() (
+  $DIG version.bind txt ch @10.53.0.1 -p ${PORT} >dig.out.test$n || return 1
+  grep "status: NOERROR" dig.out.test$n >/dev/null || return 1
+
+  try=1
+  while test $try -lt 12; do
+    [ -f $TMPDIR/example.log.$try ] && return 1
+    try=$((try + 1))
+  done
+  set -- $TMPDIR/example.log.*
+  [ "$#" -eq 1 ] || return 1
+)
+retry_quiet 5 _found2 || ret=1
+if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
+status=$((status + ret))
+
 n=$((n + 1))
 echo_i "testing unlimited versions ($n)"
 ret=0
-copy_setports ns1/named.unlimited.in ns1/named.conf
+cp ns1/named.unlimited.conf ns1/named.conf
 # a seconds since epoch version number
 touch ns1/named_unlimited.1480039317
 rndc_reconfig ns1 10.53.0.1 >rndc.out.test$n
@@ -230,11 +279,11 @@ status=$((status + ret))
 n=$((n + 1))
 echo_i "testing default logfile using named -L file ($n)"
 ret=0
-$PERL ../stop.pl logfileconfig ns1
+stop_server ns1
 cp named2.args ns1/named.args
 test -f ns1/named.pid && ret=1
 rm -f ns1/named_deflog
-copy_setports ns1/named.plainconf.in ns1/named.conf
+cp ns1/named.plainlog.conf ns1/named.conf
 start_server --noclean --restart --port ${PORT} ns1
 [ -f "ns1/named_deflog" ] || ret=1
 if [ "$ret" -ne 0 ]; then echo_i "failed"; fi
