@@ -26,9 +26,9 @@ pytestmark = pytest.mark.extra_artifacts(
         "ns*/K*",
         "ns1/255types.db",
         "ns1/example.db.compat",
-        "ns1/on-limit-kasp.db",
-        "ns1/on-limit.db",
-        "ns1/over-limit.db",
+        "ns1/below-limit-kasp.db",
+        "ns1/below-limit.db",
+        "ns1/above-limit.db",
         "ns1/under-limit-kasp.db",
         "ns1/under-limit.db",
         "ns2/db-*",
