@@ -11,18 +11,20 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-SYSTEMTESTTOP=..
-. $SYSTEMTESTTOP/conf.sh
+set -e
 
-DIGOPTS="+tcp +noadd +nosea +nostat +noquest +nocomm +nocmd"
-DIGCMD="$DIG $DIGOPTS -p ${PORT}"
-RNDCCMD="$RNDC -p ${CONTROLPORT} -c ../common/rndc.conf"
+. ../conf.sh
+
+DIGCMD="$DIG +tcp -p ${PORT}"
+RNDCCMD="$RNDC -p ${CONTROLPORT} -c ../_common/rndc.conf"
 
 status=0
 
 ret=0
 n=1
 stats=0
+nsock0nstat=0
+nsock1nstat=0
 rndc_stats() {
   _ns=$1
   _ip=$2
@@ -38,35 +40,35 @@ rndc_stats() {
 echo_i "fetching a.example from ns2's initial configuration ($n)"
 $DIGCMD +noauth a.example. @10.53.0.2 any >dig.out.ns2.1 || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "dumping initial stats for ns2 ($n)"
 rndc_stats ns2 10.53.0.2 || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "verifying adb records in named.stats ($n)"
 grep "ADB stats" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 echo_i "checking for 1 entry in adb hash table in named.stats ($n)"
 grep "1 Addresses in hash table" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "verifying cache statistics in named.stats ($n)"
 grep "Cache Statistics" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "checking for 2 entries in adb hash table in named.stats ($n)"
@@ -74,22 +76,20 @@ $DIGCMD a.example.info. @10.53.0.2 any >/dev/null 2>&1
 rndc_stats ns2 10.53.0.2 || ret=1
 grep "2 Addresses in hash table" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "dumping initial stats for ns3 ($n)"
 rndc_stats ns3 10.53.0.3 || ret=1
-if [ ! "$CYGWIN" ]; then
-  nsock0nstat=$(grep "UDP/IPv4 sockets active" $last_stats | awk '{print $1}')
-  [ 0 -ne ${nsock0nstat:-0} ] || ret=1
-fi
+nsock0nstat=$(grep "UDP/IPv4 sockets active" $last_stats | awk '{print $1}')
+[ 0 -ne ${nsock0nstat} ] || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 echo_i "sending queries to ns3"
-$DIGCMD +tries=2 +time=1 +recurse @10.53.0.3 foo.info. any >/dev/null 2>&1
+$DIGCMD +tries=2 +time=1 +recurse @10.53.0.3 foo.info. any >/dev/null 2>&1 || true
 
 ret=0
 echo_i "dumping updated stats for ns3 ($n)"
@@ -99,32 +99,30 @@ getstats() {
 }
 retry_quiet 5 getstats || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "verifying recursing clients output in named.stats ($n)"
 grep "2 recursing clients" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "verifying active fetches output in named.stats ($n)"
 grep "1 active fetches" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
-if [ ! "$CYGWIN" ]; then
-  ret=0
-  echo_i "verifying active sockets output in named.stats ($n)"
-  nsock1nstat=$(grep "UDP/IPv4 sockets active" $last_stats | awk '{print $1}')
-  [ $(expr ${nsock1nstat:-0} - ${nsock0nstat:-0}) -eq 1 ] || ret=1
-  if [ $ret != 0 ]; then echo_i "failed"; fi
-  status=$(expr $status + $ret)
-  n=$(expr $n + 1)
-fi
+ret=0
+echo_i "verifying active sockets output in named.stats ($n)"
+nsock1nstat=$(grep "UDP/IPv4 sockets active" $last_stats | awk '{print $1}')
+[ $((nsock1nstat - nsock0nstat)) -eq 1 ] || ret=1
+if [ $ret != 0 ]; then echo_i "failed"; fi
+status=$((status + ret))
+n=$((n + 1))
 
 # there should be 1 UDP and no TCP queries.  As the TCP counter is zero
 # no status line is emitted.
@@ -133,54 +131,59 @@ echo_i "verifying queries in progress in named.stats ($n)"
 grep "1 UDP queries in progress" $last_stats >/dev/null || ret=1
 grep "TCP queries in progress" $last_stats >/dev/null && ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "verifying bucket size output ($n)"
 grep "bucket size" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "checking priming queries are counted ($n)"
 grep "priming queries" $last_stats >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "checking that zones with slash are properly shown in XML output ($n)"
-if $FEATURETEST --have-libxml2 && [ -x ${CURL} ]; then
+if $FEATURETEST --have-libxml2 && [ -x "${CURL}" ] && [ -x "${XMLLINT}" ]; then
   ${CURL} http://10.53.0.1:${EXTRAPORT1}/xml/v3/zones >curl.out.${n} 2>/dev/null || ret=1
-  grep '<zone name="32/1.0.0.127-in-addr.example" rdataclass="IN">' curl.out.${n} >/dev/null || ret=1
+  test -n "$("$XMLLINT" --xpath '/statistics/views/view[@name="_default"]/zones/zone[@name="32/1.0.0.127-in-addr.example"]' curl.out.${n})" || ret=1
 else
-  echo_i "skipping test as libxml2 and/or curl was not found"
+  echo_i "skipping test as libxml2 and/or curl and/or xmllint was not found"
 fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "checking that zones return their type ($n)"
-if $FEATURETEST --have-libxml2 && [ -x ${CURL} ]; then
+if $FEATURETEST --have-libxml2 && [ -x "${CURL}" ] && [ -x "${XMLLINT}" ]; then
   ${CURL} http://10.53.0.1:${EXTRAPORT1}/xml/v3/zones >curl.out.${n} 2>/dev/null || ret=1
-  grep '<zone name="32/1.0.0.127-in-addr.example" rdataclass="IN"><type>master</type>' curl.out.${n} >/dev/null || ret=1
+  test -n "$("$XMLLINT" --xpath '/statistics/views/view[@name="_default"]/zones/zone[@name="32/1.0.0.127-in-addr.example"]/type[text()="primary"]' curl.out.${n})" || ret=1
 else
-  echo_i "skipping test as libxml2 and/or curl was not found"
+  echo_i "skipping test as libxml2 and/or curl and/or xmllint was not found"
 fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "checking bind9.xsl vs xml ($n)"
-if $FEATURETEST --have-libxml2 && [ -x "${CURL}" ] && [ -x "${XSLTPROC}" ]; then
-  $DIGCMD +notcp +recurse @10.53.0.3 soa . >/dev/null 2>&1
-  $DIGCMD +notcp +recurse @10.53.0.3 soa example >/dev/null 2>&1
-  ${CURL} http://10.53.0.3:${EXTRAPORT1}/xml/v3 >curl.out.${n}.xml 2>/dev/null || ret=1
-  ${CURL} http://10.53.0.3:${EXTRAPORT1}/bind9.xsl >curl.out.${n}.xsl 2>/dev/null || ret=1
+if $FEATURETEST --have-libxml2 && "${CURL}" --http1.1 http://10.53.0.3:${EXTRAPORT1} >/dev/null 2>&1 && [ -x "${XSLTPROC}" ]; then
+  $DIGCMD +notcp +recurse @10.53.0.3 soa . >dig.out.test$n.1 2>&1
+  $DIGCMD +notcp +recurse @10.53.0.3 soa example >dig.out.test$n.2 2>&1
+  # check multiple requests over the same socket
+  time1=$($PERL -e 'print time(), "\n";')
+  ${CURL} --http1.1 -o curl.out.${n}.xml http://10.53.0.3:${EXTRAPORT1}/xml/v3 \
+    -o curl.out.${n}.xsl http://10.53.0.3:${EXTRAPORT1}/bind9.xsl 2>/dev/null || ret=1
+  time2=$($PERL -e 'print time(), "\n";')
+  test $((time2 - time1)) -lt 5 || ret=1
+  diff ${TOP_SRCDIR}/bin/named/bind9.xsl curl.out.${n}.xsl || ret=1
   ${XSLTPROC} curl.out.${n}.xsl - <curl.out.${n}.xml >xsltproc.out.${n} 2>/dev/null || ret=1
   cp curl.out.${n}.xml stats.xml.out || ret=1
 
@@ -195,7 +198,7 @@ if $FEATURETEST --have-libxml2 && [ -x "${CURL}" ] && [ -x "${XSLTPROC}" ]; then
   grep "<h3>View " xsltproc.out.${n} >/dev/null || ret=1
   grep "<h2>Server Statistics</h2>" xsltproc.out.${n} >/dev/null || ret=1
   grep "<h2>Zone Maintenance Statistics</h2>" xsltproc.out.${n} >/dev/null || ret=1
-  grep "<h2>Resolver Statistics (Common)</h2>" xsltproc.out.${n} >/dev/null || ret=1
+  # grep "<h2>Resolver Statistics (Common)</h2>" xsltproc.out.${n} >/dev/null || ret=1
   grep "<h3>Resolver Statistics for View " xsltproc.out.${n} >/dev/null || ret=1
   grep "<h3>ADB Statistics for View " xsltproc.out.${n} >/dev/null || ret=1
   grep "<h3>Cache Statistics for View " xsltproc.out.${n} >/dev/null || ret=1
@@ -216,41 +219,38 @@ if $FEATURETEST --have-libxml2 && [ -x "${CURL}" ] && [ -x "${XSLTPROC}" ]; then
   # grep "<h2>Glue cache statistics</h2>" xsltproc.out.${n} >/dev/null || ret=1
   grep "<h3>View _default" xsltproc.out.${n} >/dev/null || ret=1
   grep "<h4>Zone example" xsltproc.out.${n} >/dev/null || ret=1
-  grep "<h2>Network Status</h2>" xsltproc.out.${n} >/dev/null || ret=1
-  grep "<h2>Task Manager Configuration</h2>" xsltproc.out.${n} >/dev/null || ret=1
-  grep "<h2>Tasks</h2>" xsltproc.out.${n} >/dev/null || ret=1
   grep "<h2>Memory Usage Summary</h2>" xsltproc.out.${n} >/dev/null || ret=1
   grep "<h2>Memory Contexts</h2>" xsltproc.out.${n} >/dev/null || ret=1
 else
-  echo_i "skipping test as libxml2 and/or curl and/or xsltproc was not found"
+  echo_i "skipping test as libxml2 and/or curl with HTTP/1.1 support and/or xsltproc was not found"
 fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 ret=0
 echo_i "checking bind9.xml socket statistics ($n)"
-if $FEATURETEST --have-libxml2 && [ -x "${CURL}" ] && [ -x "${XSLTPROC}" ]; then
+if $FEATURETEST --have-libxml2 && [ -e stats.xml.out ] && [ -x "${XSLTPROC}" ] && [ -x "${XMLLINT}" ]; then
   # Socket statistics (expect no errors)
-  grep "<counter name=\"TCP4AcceptFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP4BindFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP4ConnFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP4OpenFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP4RecvErr\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP4SendErr\">0</counter>" stats.xml.out >/dev/null || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP4AcceptFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP4BindFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP4ConnFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP4OpenFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP4RecvErr" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  # [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP4SendErr" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
 
-  grep "<counter name=\"TCP6AcceptFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP6BindFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP6ConnFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP6OpenFail\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP6RecvErr\">0</counter>" stats.xml.out >/dev/null || ret=1
-  grep "<counter name=\"TCP6SendErr\">0</counter>" stats.xml.out >/dev/null || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP6AcceptFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP6BindFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP6ConnFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP6OpenFail" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP6RecvErr" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
+  [ "$("$XMLLINT" --xpath 'count(/statistics/server/counters[@type="sockstat"]/counter[@name="TCP6SendErr" and text()="0"])' stats.xml.out)" -eq 1 ] || ret=1
 else
-  echo_i "skipping test as libxml2 and/or curl and/or xsltproc was not found"
+  echo_i "skipping test as libxml2 and/or stats.xml.out file and/or xsltproc and/or xmllint was not found"
 fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 echo_i "Check that 'zone-statistics full;' is processed by 'rndc reconfig' ($n)"
 ret=0
@@ -258,23 +258,23 @@ ret=0
 rndc_stats ns2 10.53.0.2 || ret=1
 sed -n '/Per Zone Query Statistics/,/^++/p' $last_stats | grep -F '[example]' >/dev/null && ret=0
 # turn on
-copy_setports ns2/named2.conf.in ns2/named.conf
+cp ns2/named2.conf ns2/named.conf
 rndc_reconfig ns2 10.53.0.2
 rndc_stats ns2 10.53.0.2 || ret=1
 sed -n '/Per Zone Query Statistics/,/^++/p' $last_stats | grep -F '[example]' >/dev/null || ret=1
 # turn off
-copy_setports ns2/named.conf.in ns2/named.conf
+cp ns2/named1.conf ns2/named.conf
 rndc_reconfig ns2 10.53.0.2
 rndc_stats ns2 10.53.0.2 || ret=1
 sed -n '/Per Zone Query Statistics/,/^++/p' $last_stats | grep -F '[example]' >/dev/null && ret=0
 # turn on
-copy_setports ns2/named2.conf.in ns2/named.conf
+cp ns2/named2.conf ns2/named.conf
 rndc_reconfig ns2 10.53.0.2
 rndc_stats ns2 10.53.0.2 || ret=1
 sed -n '/Per Zone Query Statistics/,/^++/p' $last_stats | grep -F '[example]' >/dev/null || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=$(expr $status + $ret)
-n=$(expr $n + 1)
+status=$((status + ret))
+n=$((n + 1))
 
 echo_i "exit status: $status"
 [ $status -eq 0 ] || exit 1
