@@ -12,10 +12,6 @@
 # information regarding copyright ownership.
 
 # shellcheck source=conf.sh
-. "$SYSTEMTESTTOP/conf.sh"
-
-for conf in ns*/named.conf.in; do
-  copy_setports "$conf" "$(dirname "$conf")/$(basename "$conf" .in)"
-done
+. ../conf.sh
 
 (cd ns2 && $SHELL sign.sh)
