@@ -13,14 +13,11 @@
 
 . ../conf.sh
 
-copy_setports ns1/named.conf.in ns1/named.conf
-
 #
 # Generate a large enough zone, so the transfer takes longer than
 # tcp-initial-timeout interval
 #
 $PYTHON -c "
-from __future__ import print_function
 print('large IN TXT', end=' ')
 for a in range(128):
     print('\"%s\"' % ('A' * 240), end=' ')
