@@ -13,9 +13,8 @@
 
 set -e
 
-SYSTEMTESTTOP=..
 # shellcheck source=conf.sh
-. $SYSTEMTESTTOP/conf.sh
+. ../conf.sh
 
 dig_with_opts() {
   "$DIG" +tcp +noadd +nosea +nostat +noquest +nocomm +nocmd +noauth -p "${PORT}" "$@"
@@ -25,7 +24,7 @@ dig_with_shortopts() {
   "$DIG" +tcp +short -p "${PORT}" "$@"
 }
 
-RNDCCMD="$RNDC -c $SYSTEMTESTTOP/common/rndc.conf -p ${CONTROLPORT} -s"
+RNDCCMD="$RNDC -c ../_common/rndc.conf -p ${CONTROLPORT} -s"
 
 status=0
 
@@ -38,8 +37,8 @@ dig_with_opts a.example. @10.53.0.3 any >dig.out.ns3.1 || status=1
 echo_i "copying in new configurations for ns2 and ns3"
 rm -f ns2/named.conf ns3/named.conf ns2/example.db
 cp -f ns2/example2.db ns2/example.db
-copy_setports ns2/named2.conf.in ns2/named.conf
-copy_setports ns3/named2.conf.in ns3/named.conf
+cp ns2/named2.conf ns2/named.conf
+cp ns3/named2.conf ns3/named.conf
 
 echo_i "reloading ns2 and ns3 with rndc"
 nextpart ns2/named.run >/dev/null
@@ -138,8 +137,8 @@ ret=0
 wait_for_signed() {
   "$DIG" -p "${PORT}" @10.53.0.2 -b 10.53.0.2 +dnssec DNSKEY inline >dig.out.internal
   "$DIG" -p "${PORT}" @10.53.0.2 -b 10.53.0.5 +dnssec DNSKEY inline >dig.out.external
-  grep "ANSWER: 4," dig.out.internal >/dev/null || return 1
-  grep "ANSWER: 4," dig.out.external >/dev/null || return 1
+  grep "ANSWER: 3," dig.out.internal >/dev/null || return 1
+  grep "ANSWER: 3," dig.out.external >/dev/null || return 1
   return 0
 }
 retry_quiet 10 wait_for_signed || ret=1
@@ -152,7 +151,7 @@ status=$((status + ret))
 echo_i "verifying adding of multiple inline zones followed by reconfiguration works"
 
 [ ! -f ns2/zones.conf ] && touch ns2/zones.conf
-copy_setports ns2/named3.conf.in ns2/named.conf
+cp ns2/named3.conf ns2/named.conf
 
 i=1
 while [ $i -lt 50 ]; do
@@ -162,10 +161,9 @@ while [ $i -lt 50 ]; do
   # Add a new zone to the configuration.
   cat >>ns2/zones.conf <<-EOF
 	zone "${zone_name}" {
-	    type master;
+	    type primary;
 	    file "db.${zone_name}";
-	    dnssec-dnskey-kskonly yes;
-	    auto-dnssec maintain;
+	    dnssec-policy default;
 	    inline-signing yes;
 	};
 	EOF
@@ -184,7 +182,6 @@ while [ $i -lt 50 ]; do
 	localhost       IN      A       127.0.0.1
 	EOF
 
-  $KEYGEN -q -Kns2 -fk -aecdsa256 "${zone_name}" >/dev/null
   $RNDCCMD 10.53.0.2 reconfig || ret=1
   if [ $ret != 0 ]; then
     echo_i "failed"
