@@ -51,7 +51,7 @@
 #define TOTEXTTYPE  "rdata->type"
 #define TOTEXTDEF   "use_default = true"
 
-#define FROMWIREARGS  "rdclass, type, source, dctx, options, target"
+#define FROMWIREARGS  "rdclass, type, source, dctx, target"
 #define FROMWIRECLASS "rdclass"
 #define FROMWIRETYPE  "type"
 #define FROMWIREDEF   "use_default = true"
@@ -135,7 +135,7 @@ static const char copyright[] = "/*\n"
 
 static struct cc {
 	struct cc *next;
-	int rdclass;
+	uint16_t rdclass;
 	char classbuf[TYPECLASSBUF];
 } *classes;
 
@@ -152,11 +152,12 @@ static struct ttnam {
 	char typebuf[TYPECLASSBUF];
 	char macroname[TYPECLASSBUF];
 	char attr[ATTRIBUTESIZE];
-	unsigned int sorted;
+	bool todo;
+	uint8_t hash;
 	uint16_t type;
 } typenames[TYPENAMES];
 
-static int maxtype = -1;
+static int ttnam_count;
 
 typedef struct {
 	DIR *handle;
@@ -177,14 +178,27 @@ sd(unsigned int, const char *, const char *, char);
 static void
 insert_into_typenames(int, const char *, const char *);
 
+static uint8_t
+HASH(char *string) {
+	size_t n;
+	unsigned char a, b;
+
+	n = strlen(string);
+	INSIST(n > 0);
+	a = tolower((unsigned char)string[0]);
+	b = tolower((unsigned char)string[n - 1]);
+
+	return ((a + n) * b) % 256;
+}
+
 static bool
 start_directory(const char *path, isc_dir_t *dir) {
 	dir->handle = opendir(path);
 
 	if (dir->handle != NULL) {
-		return (true);
+		return true;
 	} else {
-		return (false);
+		return false;
 	}
 }
 
@@ -210,9 +224,9 @@ next_file(isc_dir_t *dir) {
 	}
 
 	if (dir->filename != NULL) {
-		return (true);
+		return true;
 	} else {
-		return (false);
+		return false;
 	}
 }
 
@@ -247,7 +261,7 @@ upper(char *s) {
 		*b++ = islower(c) ? toupper(c) : c;
 	}
 	*b = '\0';
-	return (buf[buf_to_use]);
+	return buf[buf_to_use];
 }
 
 static char *
@@ -260,7 +274,7 @@ funname(const char *s, char *buf) {
 		*b++ = (c == '-') ? '_' : c;
 	}
 	*b = '\0';
-	return (buf);
+	return buf;
 }
 
 static void
@@ -336,18 +350,6 @@ doswitch(const char *name, const char *function, const char *args,
 	}
 }
 
-static struct ttnam *
-find_typename(int type) {
-	int i;
-
-	for (i = 0; i < TYPENAMES; i++) {
-		if (typenames[i].typebuf[0] != 0 && typenames[i].type == type) {
-			return (&typenames[i]);
-		}
-	}
-	return (NULL);
-}
-
 static void
 insert_into_typenames(int type, const char *typebuf, const char *attr) {
 	struct ttnam *ttn = NULL;
@@ -356,22 +358,25 @@ insert_into_typenames(int type, const char *typebuf, const char *attr) {
 	char tmp[256];
 
 	INSIST(strlen(typebuf) < TYPECLASSBUF);
-	for (i = 0; i < TYPENAMES; i++) {
-		if (typenames[i].typebuf[0] != 0 && typenames[i].type == type &&
-		    strcmp(typebuf, typenames[i].typebuf) != 0)
-		{
+	for (i = 0; i < TYPENAMES && typenames[i].typebuf[0] != 0; i++) {
+		if (typenames[i].type != type) {
+			continue;
+		}
+		if (strcmp(typebuf, typenames[i].typebuf) != 0) {
 			fprintf(stderr,
-				"Error:  type %d has two names: %s, %s\n", type,
+				"Error: type %d has two names: %s, %s\n", type,
 				typenames[i].typebuf, typebuf);
 			exit(EXIT_FAILURE);
 		}
-		if (typenames[i].typebuf[0] == 0 && ttn == NULL) {
-			ttn = &typenames[i];
-		}
+		ttn = &typenames[i];
 	}
-	if (ttn == NULL) {
+	/* Subtract one to leave an empty sentinel entry at the end */
+	if (i >= TYPENAMES - 1) {
 		fprintf(stderr, "Error: typenames array too small\n");
 		exit(EXIT_FAILURE);
+	} else if (ttn == NULL) {
+		ttn = &typenames[i];
+		ttnam_count = i + 1;
 	}
 
 	/* XXXMUKS: This is redundant due to the INSIST above. */
@@ -398,7 +403,7 @@ insert_into_typenames(int type, const char *typebuf, const char *attr) {
 	if (attr == NULL) {
 		n = snprintf(tmp, sizeof(tmp), "RRTYPE_%s_ATTRIBUTES",
 			     upper(ttn->macroname));
-		INSIST(n > 0 && (unsigned)n < sizeof(tmp));
+		INSIST(n > 0 && (unsigned int)n < sizeof(tmp));
 		attr = tmp;
 	}
 
@@ -419,10 +424,8 @@ insert_into_typenames(int type, const char *typebuf, const char *attr) {
 	strncpy(ttn->attr, attr, sizeof(ttn->attr));
 	ttn->attr[sizeof(ttn->attr) - 1] = '\0';
 
-	ttn->sorted = 0;
-	if (maxtype < type) {
-		maxtype = type;
-	}
+	ttn->hash = HASH(ttn->typebuf);
+	ttn->todo = true;
 }
 
 static void
@@ -469,16 +472,12 @@ add(unsigned int rdclass, const char *classbuf, int type, const char *typebuf,
 	}
 
 	while ((tt != NULL) && (tt->type == type) && (tt->rdclass < rdclass)) {
-		if (strcmp(tt->typebuf, typebuf) != 0) {
-			exit(EXIT_FAILURE);
-		}
+		INSIST(strcmp(tt->typebuf, typebuf) == 0);
 		oldtt = tt;
 		tt = tt->next;
 	}
 
-	if ((tt != NULL) && (tt->type == type) && (tt->rdclass == rdclass)) {
-		exit(EXIT_FAILURE);
-	}
+	INSIST(tt == NULL || tt->type != type || tt->rdclass != rdclass);
 
 	newtt->next = tt;
 	if (oldtt != NULL) {
@@ -548,7 +547,7 @@ sd(unsigned int rdclass, const char *classbuf, const char *dirbuf,
 		 */
 		n = snprintf(buf, sizeof(buf), "%s_%u.%c", typebuf, type,
 			     filetype);
-		INSIST(n > 0 && (unsigned)n < sizeof(buf));
+		INSIST(n > 0 && (unsigned int)n < sizeof(buf));
 		if (strcmp(buf, dir.filename) != 0) {
 			continue;
 		}
@@ -563,20 +562,10 @@ sd(unsigned int rdclass, const char *classbuf, const char *dirbuf,
 	end_directory(&dir);
 }
 
-static unsigned int
-HASH(char *string) {
-	size_t n;
-	unsigned char a, b;
-
-	n = strlen(string);
-	if (n == 0) {
-		fprintf(stderr, "n == 0?\n");
-		exit(EXIT_FAILURE);
-	}
-	a = tolower((unsigned char)string[0]);
-	b = tolower((unsigned char)string[n - 1]);
-
-	return (((a + n) * b) % 256);
+static int
+ttnam_cmp(const void *va, const void *vb) {
+	const struct ttnam *ttna = va, *ttnb = vb;
+	return ttna->type - ttnb->type;
 }
 
 int
@@ -588,7 +577,6 @@ main(int argc, char **argv) {
 	struct tt *tt;
 	struct cc *cc;
 	struct ttnam *ttn, *ttn2;
-	unsigned int hash;
 	time_t now;
 	char year[11];
 	int lasttype;
@@ -597,7 +585,7 @@ main(int argc, char **argv) {
 	int type_enum = 0;
 	int structs = 0;
 	int depend = 0;
-	int c, i, j, n;
+	int c, n;
 	char buf1[TYPECLASSBUF];
 	char filetype = 'c';
 	FILE *fd;
@@ -609,10 +597,6 @@ main(int argc, char **argv) {
 	char *endptr;
 	isc_dir_t dir;
 
-	for (i = 0; i < TYPENAMES; i++) {
-		memset(&typenames[i], 0, sizeof(typenames[i]));
-	}
-
 	srcdir[0] = '\0';
 	while ((c = getopt(argc, argv, "cdits:F:P:S:")) != -1) {
 		switch (c) {
@@ -657,7 +641,7 @@ main(int argc, char **argv) {
 				exit(EXIT_FAILURE);
 			}
 			n = snprintf(srcdir, sizeof(srcdir), "%s/", optarg);
-			INSIST(n > 0 && (unsigned)n < sizeof(srcdir));
+			INSIST(n > 0 && (unsigned int)n < sizeof(srcdir));
 			break;
 		case 'F':
 			file = optarg;
@@ -674,11 +658,9 @@ main(int argc, char **argv) {
 	}
 
 	n = snprintf(buf, sizeof(buf), "%srdata", srcdir);
-	INSIST(n > 0 && (unsigned)n < sizeof(srcdir));
+	INSIST(n > 0 && (unsigned int)n < sizeof(srcdir));
 
-	if (!start_directory(buf, &dir)) {
-		exit(EXIT_FAILURE);
-	}
+	INSIST(start_directory(buf, &dir));
 
 	while (next_file(&dir)) {
 		if (sscanf(dir.filename, TYPECLASSFMT, classbuf, &rdclass) != 2)
@@ -693,7 +675,7 @@ main(int argc, char **argv) {
 		 */
 		n = snprintf(buf, sizeof(buf), "%srdata/%s_%u", srcdir,
 			     classbuf, rdclass);
-		INSIST(n > 0 && (unsigned)n < sizeof(buf));
+		INSIST(n > 0 && (unsigned int)n < sizeof(buf));
 		if (strcmp(buf + 6 + strlen(srcdir), dir.filename) != 0) {
 			continue;
 		}
@@ -706,7 +688,7 @@ main(int argc, char **argv) {
 	}
 	end_directory(&dir);
 	n = snprintf(buf, sizeof(buf), "%srdata/generic", srcdir);
-	INSIST(n > 0 && (unsigned)n < sizeof(srcdir));
+	INSIST(n > 0 && (unsigned int)n < sizeof(srcdir));
 	sd(0, "", buf, filetype);
 
 	source_date_epoch = getenv("SOURCE_DATE_EPOCH");
@@ -757,7 +739,7 @@ main(int argc, char **argv) {
 		if (tm != NULL && tm->tm_year > 104) {
 			n = snprintf(year, sizeof(year), "-%d",
 				     tm->tm_year + 1900);
-			INSIST(n > 0 && (unsigned)n < sizeof(year));
+			INSIST(n > 0 && (unsigned int)n < sizeof(year));
 		} else {
 			snprintf(year, sizeof(year), "-2016");
 		}
@@ -816,8 +798,6 @@ main(int argc, char **argv) {
 		 * attributes.
 		 */
 
-#define PRINT_COMMA(x) (x == maxtype ? "" : ",")
-
 #define METANOTQUESTION             \
 	"DNS_RDATATYPEATTR_META | " \
 	"DNS_RDATATYPEATTR_NOTQUESTION"
@@ -841,6 +821,12 @@ main(int argc, char **argv) {
 		insert_into_typenames(254, "maila", METAQUESTIONONLY);
 		insert_into_typenames(255, "any", METAQUESTIONONLY);
 
+		/*
+		 * For reproducible builds, ensure the directory read
+		 * order does not affect the order of switch cases.
+		 */
+		qsort(typenames, ttnam_count, sizeof(struct ttnam), ttnam_cmp);
+
 		/*
 		 * Spit out a quick and dirty hash function.  Here,
 		 * we walk through the list of type names, and calculate
@@ -867,37 +853,27 @@ main(int argc, char **argv) {
 		printf("#define RDATATYPE_FROMTEXT_SW(_hash,"
 		       "_typename,_length,_typep) \\\n");
 		printf("\tswitch (_hash) { \\\n");
-		for (i = 0; i <= maxtype; i++) {
-			ttn = find_typename(i);
-			if (ttn == NULL) {
-				continue;
-			}
-
+		for (ttn = typenames; ttn->typebuf[0] != 0; ttn++) {
 			/*
 			 * Skip entries we already processed.
 			 */
-			if (ttn->sorted != 0) {
+			if (!ttn->todo) {
 				continue;
 			}
 
-			hash = HASH(ttn->typebuf);
-			printf("\t\tcase %u: \\\n", hash);
+			printf("\t\tcase %u: \\\n", ttn->hash);
 
 			/*
 			 * Find all other entries that happen to match
 			 * this hash.
 			 */
-			for (j = 0; j <= maxtype; j++) {
-				ttn2 = find_typename(j);
-				if (ttn2 == NULL) {
-					continue;
-				}
-				if (hash == HASH(ttn2->typebuf)) {
+			for (ttn2 = typenames; ttn2->typebuf[0] != 0; ttn2++) {
+				if (ttn2->todo && ttn2->hash == ttn->hash) {
 					printf("\t\t\tRDATATYPE_COMPARE"
 					       "(\"%s\", %d, _typename, "
 					       " _length, _typep); \\\n",
 					       ttn2->typebuf, ttn2->type);
-					ttn2->sorted = 1;
+					ttn2->todo = false;
 				}
 			}
 			printf("\t\t\tbreak; \\\n");
@@ -906,35 +882,27 @@ main(int argc, char **argv) {
 
 		printf("#define RDATATYPE_ATTRIBUTE_SW \\\n");
 		printf("\tswitch (type) { \\\n");
-		for (i = 0; i <= maxtype; i++) {
-			ttn = find_typename(i);
-			if (ttn == NULL) {
-				continue;
-			}
-			printf("\tcase %d: return (%s); \\\n", i,
+		for (ttn = typenames; ttn->typebuf[0] != 0; ttn++) {
+			printf("\tcase %d: return (%s); \\\n", ttn->type,
 			       upper(ttn->attr));
 		}
 		printf("\t}\n");
 
 		printf("#define RDATATYPE_TOTEXT_SW \\\n");
 		printf("\tswitch (type) { \\\n");
-		for (i = 0; i <= maxtype; i++) {
-			ttn = find_typename(i);
-			if (ttn == NULL) {
-				continue;
-			}
+		for (ttn = typenames; ttn->typebuf[0] != 0; ttn++) {
 			/*
 			 * Remove KEYDATA (65533) from the type to memonic
 			 * translation as it is internal use only.  This
 			 * stops the tools from displaying KEYDATA instead
 			 * of TYPE65533.
 			 */
-			if (i == 65533U) {
+			if (ttn->type == 65533U) {
 				continue;
 			}
 			printf("\tcase %d: return "
 			       "(str_totext(\"%s\", target)); \\\n",
-			       i, upper(ttn->typebuf));
+			       ttn->type, upper(ttn->typebuf));
 		}
 		printf("\t}\n");
 	} else if (type_enum) {
@@ -1058,5 +1026,5 @@ main(int argc, char **argv) {
 		exit(EXIT_FAILURE);
 	}
 
-	return (0);
+	return 0;
 }
