@@ -42,7 +42,6 @@
 #include <isc/lex.h>
 #include <isc/mem.h>
 #include <isc/once.h>
-#include <isc/print.h>
 #include <isc/random.h>
 #include <isc/result.h>
 #include <isc/string.h>
@@ -93,13 +92,6 @@ static gss_OID_desc __gss_spnego_mechanism_oid_desc = {
 		(r).base = (gb).value;                  \
 	} while (0)
 
-#define RETERR(x)                            \
-	do {                                 \
-		result = (x);                \
-		if (result != ISC_R_SUCCESS) \
-			goto out;            \
-	} while (0)
-
 static void
 name_to_gbuffer(const dns_name_t *name, isc_buffer_t *buffer,
 		gss_buffer_desc *gbuffer) {
@@ -118,7 +110,8 @@ name_to_gbuffer(const dns_name_t *name, isc_buffer_t *buffer,
 		namep = &tname;
 	}
 
-	result = dns_name_toprincipal(namep, buffer);
+	result = dns_name_totext(
+		namep, DNS_NAME_OMITFINALDOT | DNS_NAME_PRINCIPAL, buffer);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 	isc_buffer_putuint8(buffer, 0);
 	isc_buffer_usedregion(buffer, &r);
@@ -384,7 +377,8 @@ dst_gssapi_identitymatchesrealmkrb5(const dns_name_t *signer,
 	 * a string, and do string operations on them.
 	 */
 	isc_buffer_init(&buffer, sbuf, sizeof(sbuf));
-	result = dns_name_toprincipal(signer, &buffer);
+	result = dns_name_totext(
+		signer, DNS_NAME_OMITFINALDOT | DNS_NAME_PRINCIPAL, &buffer);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 	isc_buffer_putuint8(&buffer, 0);
 	dns_name_format(realm, rbuf, sizeof(rbuf));
@@ -432,7 +426,8 @@ dst_gssapi_identitymatchesrealmkrb5(const dns_name_t *signer,
 		dns_name_t *machine;
 
 		machine = dns_fixedname_initname(&fixed);
-		result = dns_name_fromstring(machine, sname, 0, NULL);
+		result = dns_name_fromstring(machine, sname, dns_rootname, 0,
+					     NULL);
 		if (result != ISC_R_SUCCESS) {
 			return false;
 		}
@@ -461,7 +456,8 @@ dst_gssapi_identitymatchesrealmms(const dns_name_t *signer,
 	 * a string, and do string operations on them.
 	 */
 	isc_buffer_init(&buffer, sbuf, sizeof(sbuf));
-	result = dns_name_toprincipal(signer, &buffer);
+	result = dns_name_totext(
+		signer, DNS_NAME_OMITFINALDOT | DNS_NAME_PRINCIPAL, &buffer);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 	isc_buffer_putuint8(&buffer, 0);
 	dns_name_format(realm, rbuf, sizeof(rbuf));
@@ -512,7 +508,7 @@ dst_gssapi_identitymatchesrealmms(const dns_name_t *signer,
 		dns_name_t *machine;
 
 		machine = dns_fixedname_initname(&fixed);
-		result = dns_name_fromstring2(machine, sbuf, realm, 0, NULL);
+		result = dns_name_fromstring(machine, sbuf, realm, 0, NULL);
 		if (result != ISC_R_SUCCESS) {
 			return false;
 		}
@@ -589,8 +585,7 @@ dst_gssapi_initctx(const dns_name_t *name, isc_buffer_t *intoken,
 	gret = gss_import_name(&minor, &gnamebuf, GSS_C_NO_OID, &gname);
 	if (gret != GSS_S_COMPLETE) {
 		gss_err_message(mctx, gret, minor, err_message);
-		result = ISC_R_FAILURE;
-		goto out;
+		CHECK(ISC_R_FAILURE);
 	}
 
 	if (intoken != NULL) {
@@ -621,8 +616,7 @@ dst_gssapi_initctx(const dns_name_t *name, isc_buffer_t *intoken,
 			gss_log(3, "Failure initiating security context");
 		}
 
-		result = ISC_R_FAILURE;
-		goto out;
+		CHECK(ISC_R_FAILURE);
 	}
 
 	/*
@@ -635,7 +629,7 @@ dst_gssapi_initctx(const dns_name_t *name, isc_buffer_t *intoken,
 	 */
 	if (gouttoken.length != 0U) {
 		GBUFFER_TO_REGION(gouttoken, r);
-		RETERR(isc_buffer_copyregion(outtoken, &r));
+		CHECK(isc_buffer_copyregion(outtoken, &r));
 	}
 
 	if (gret == GSS_S_COMPLETE) {
@@ -644,7 +638,7 @@ dst_gssapi_initctx(const dns_name_t *name, isc_buffer_t *intoken,
 		result = DNS_R_CONTINUE;
 	}
 
-out:
+cleanup:
 	if (gouttoken.length != 0U) {
 		(void)gss_release_buffer(&minor, &gouttoken);
 	}
@@ -749,7 +743,7 @@ dst_gssapi_acceptctx(dns_gss_cred_id_t cred, const char *gssapi_keytab,
 		isc_buffer_allocate(mctx, outtoken,
 				    (unsigned int)gouttoken.length);
 		GBUFFER_TO_REGION(gouttoken, r);
-		RETERR(isc_buffer_copyregion(*outtoken, &r));
+		CHECK(isc_buffer_copyregion(*outtoken, &r));
 		(void)gss_release_buffer(&minor, &gouttoken);
 	}
 
@@ -759,7 +753,7 @@ dst_gssapi_acceptctx(dns_gss_cred_id_t cred, const char *gssapi_keytab,
 			gss_log(3, "failed gss_display_name: %s",
 				gss_error_tostring(gret, minor, buf,
 						   sizeof(buf)));
-			RETERR(ISC_R_FAILURE);
+			CHECK(ISC_R_FAILURE);
 		}
 
 		/*
@@ -781,8 +775,8 @@ dst_gssapi_acceptctx(dns_gss_cred_id_t cred, const char *gssapi_keytab,
 		isc_buffer_init(&namebuf, r.base, r.length);
 		isc_buffer_add(&namebuf, r.length);
 
-		RETERR(dns_name_fromtext(principal, &namebuf, dns_rootname, 0,
-					 NULL));
+		CHECK(dns_name_fromtext(principal, &namebuf, dns_rootname, 0,
+					NULL));
 
 		if (gnamebuf.length != 0U) {
 			gret = gss_release_buffer(&minor, &gnamebuf);
@@ -798,7 +792,7 @@ dst_gssapi_acceptctx(dns_gss_cred_id_t cred, const char *gssapi_keytab,
 
 	*ctxout = context;
 
-out:
+cleanup:
 	if (gname != NULL) {
 		gret = gss_release_name(&minor, &gname);
 		if (gret != GSS_S_COMPLETE) {
