@@ -41,13 +41,6 @@
 
 #include <dst/dst.h>
 
-#define CHECK(x)                             \
-	do {                                 \
-		result = (x);                \
-		if (result != ISC_R_SUCCESS) \
-			goto failure;        \
-	} while (0)
-
 #define OPTOUT(x)  (((x) & DNS_NSEC3FLAG_OPTOUT) != 0)
 #define CREATE(x)  (((x) & DNS_NSEC3FLAG_CREATE) != 0)
 #define INITIAL(x) (((x) & DNS_NSEC3FLAG_INITIAL) != 0)
@@ -442,22 +435,16 @@ delnsec3(dns_db_t *db, dns_dbversion_t *version, const dns_name_t *name,
 			continue;
 		}
 
-		result = dns_difftuple_create(diff->mctx, DNS_DIFFOP_DEL, name,
-					      rdataset.ttl, &rdata, &tuple);
-		if (result != ISC_R_SUCCESS) {
-			goto failure;
-		}
-		result = do_one_tuple(&tuple, db, version, diff);
-		if (result != ISC_R_SUCCESS) {
-			goto failure;
-		}
+		CHECK(dns_difftuple_create(diff->mctx, DNS_DIFFOP_DEL, name,
+					   rdataset.ttl, &rdata, &tuple));
+		CHECK(do_one_tuple(&tuple, db, version, diff));
 	}
 	if (result != ISC_R_NOMORE) {
-		goto failure;
+		goto cleanup;
 	}
 	result = ISC_R_SUCCESS;
 
-failure:
+cleanup:
 	dns_rdataset_disassociate(&rdataset);
 cleanup_node:
 	dns_db_detachnode(db, &node);
@@ -530,7 +517,7 @@ find_nsec3(dns_rdata_nsec3_t *nsec3, dns_rdataset_t *rdataset,
 			break;
 		}
 	}
-failure:
+cleanup:
 	return result;
 }
 
@@ -602,7 +589,24 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 	 * Create the node if it doesn't exist and hold
 	 * a reference to it until we have added the NSEC3.
 	 */
-	CHECK(dns_db_findnsec3node(db, hashname, true, &newnode));
+	result = dns_db_findnsec3node(db, hashname, false, &newnode);
+	if (result != ISC_R_SUCCESS) {
+		isc_result_t tresult;
+
+		CHECK(dns_db_createiterator(db, DNS_DB_NSEC3ONLY, &dbit));
+		tresult = dns_dbiterator_seek3(dbit, hashname);
+		CHECK(dns_dbiterator_pause(dbit));
+
+		if (tresult != ISC_R_SUCCESS) {
+			/* Nothing in the NSEC3 space yet. */
+			if (!unsecure) {
+				goto addnsec3;
+			}
+			goto cleanup;
+		}
+
+		goto find_previous;
+	}
 
 	/*
 	 * Seek the iterator to the 'newnode'.
@@ -638,18 +642,19 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 			} else if (CREATE(nsec3param->flags) && OPTOUT(flags)) {
 				result = dns_nsec3_delnsec3(db, version, name,
 							    nsec3param, diff);
-				goto failure;
+				goto cleanup;
 			} else {
 				maybe_remove_unsecure = true;
 			}
 		} else {
 			dns_rdataset_disassociate(&rdataset);
 			if (result != ISC_R_NOMORE) {
-				goto failure;
+				goto cleanup;
 			}
 		}
 	}
 
+find_previous:
 	/*
 	 * Find the previous NSEC3 (if any) and update it if required.
 	 */
@@ -675,9 +680,7 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 			dns_rdataset_disassociate(&rdataset);
 			continue;
 		}
-		if (result != ISC_R_SUCCESS) {
-			goto failure;
-		}
+		CHECK(result);
 
 		if (maybe_remove_unsecure) {
 			dns_rdataset_disassociate(&rdataset);
@@ -689,7 +692,7 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 			if (OPTOUT(nsec3.flags)) {
 				result = dns_nsec3_delnsec3(db, version, name,
 							    nsec3param, diff);
-				goto failure;
+				goto cleanup;
 			}
 			goto addnsec3;
 		} else {
@@ -699,7 +702,7 @@ dns_nsec3_addnsec3(dns_db_t *db, dns_dbversion_t *version,
 			 */
 			if (OPTOUT(nsec3.flags) && unsecure) {
 				dns_rdataset_disassociate(&rdataset);
-				goto failure;
+				goto cleanup;
 			}
 		}
 
@@ -737,6 +740,10 @@ addnsec3:
 	/*
 	 * Create the NSEC3 RDATA.
 	 */
+	if (newnode == NULL) {
+		CHECK(dns_db_findnsec3node(db, hashname, true, &newnode));
+	}
+
 	CHECK(dns_db_findnode(db, name, false, &node));
 	CHECK(dns_nsec3_buildrdata(db, version, node, hash, flags, iterations,
 				   salt, salt_length, nexthash, next_length,
@@ -779,7 +786,7 @@ addnsec3:
 		/*
 		 * Create the node if it doesn't exist and hold
 		 * a reference to it until we have added the NSEC3
-		 * or we discover we don't need to add make a change.
+		 * or we discover we don't need to make a change.
 		 */
 		CHECK(dns_db_findnsec3node(db, hashname, true, &newnode));
 		result = dns_db_findrdataset(db, newnode, version,
@@ -793,8 +800,19 @@ addnsec3:
 				break;
 			}
 			if (result != ISC_R_NOMORE) {
-				goto failure;
+				goto cleanup;
 			}
+		} else if (result == ISC_R_NOTFOUND) {
+			/*
+			 * If we didn't find an NSEC3 in the node,
+			 * then the node must have been newly created
+			 * by dns_db_findnsec3node(). The iterator
+			 * needs to be updated so we can seek for
+			 * the node's predecessor.
+			 */
+			dns_dbiterator_destroy(&dbit);
+			CHECK(dns_db_createiterator(db, DNS_DB_NSEC3ONLY,
+						    &dbit));
 		}
 
 		/*
@@ -822,9 +840,7 @@ addnsec3:
 				dns_rdataset_disassociate(&rdataset);
 				continue;
 			}
-			if (result != ISC_R_SUCCESS) {
-				goto failure;
-			}
+			CHECK(result);
 
 			old_next = nsec3.next;
 			old_length = nsec3.next_length;
@@ -884,7 +900,7 @@ addnsec3:
 	/* result cannot be ISC_R_NOMORE here */
 	INSIST(result != ISC_R_NOMORE);
 
-failure:
+cleanup:
 	if (dbit != NULL) {
 		dns_dbiterator_destroy(&dbit);
 	}
@@ -958,7 +974,7 @@ dns_nsec3_addnsec3s(dns_db_t *db, dns_dbversion_t *version,
 		result = ISC_R_SUCCESS;
 	}
 
-failure:
+cleanup:
 	if (dns_rdataset_isassociated(&rdataset)) {
 		dns_rdataset_disassociate(&rdataset);
 	}
@@ -999,7 +1015,7 @@ void
 dns_nsec3param_toprivate(dns_rdata_t *src, dns_rdata_t *target,
 			 dns_rdatatype_t privatetype, unsigned char *buf,
 			 size_t buflen) {
-	REQUIRE(buflen >= src->length + 1);
+	REQUIRE(buflen >= (unsigned int)src->length + 1);
 
 	REQUIRE(DNS_RDATA_INITIALIZED(target));
 
@@ -1031,7 +1047,7 @@ rr_exists(dns_db_t *db, dns_dbversion_t *ver, const dns_name_t *name,
 	if (result == ISC_R_NOTFOUND) {
 		*flag = false;
 		result = ISC_R_SUCCESS;
-		goto failure;
+		goto cleanup;
 	}
 
 	for (result = dns_rdataset_first(&rdataset); result == ISC_R_SUCCESS;
@@ -1051,7 +1067,7 @@ rr_exists(dns_db_t *db, dns_dbversion_t *ver, const dns_name_t *name,
 		result = ISC_R_SUCCESS;
 	}
 
-failure:
+cleanup:
 	if (node != NULL) {
 		dns_db_detachnode(db, &node);
 	}
@@ -1123,9 +1139,7 @@ dns_nsec3param_deletechains(dns_db_t *db, dns_dbversion_t *ver,
 	if (result == ISC_R_NOTFOUND) {
 		goto try_private;
 	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
-	}
+	CHECK(result);
 
 	for (result = dns_rdataset_first(&rdataset); result == ISC_R_SUCCESS;
 	     result = dns_rdataset_next(&rdataset))
@@ -1152,23 +1166,23 @@ dns_nsec3param_deletechains(dns_db_t *db, dns_dbversion_t *ver,
 		dns_rdata_reset(&rdata);
 	}
 	if (result != ISC_R_NOMORE) {
-		goto failure;
+		goto cleanup;
 	}
 
 	dns_rdataset_disassociate(&rdataset);
 
 try_private:
 	if (privatetype == 0) {
-		goto success;
+		result = ISC_R_SUCCESS;
+		goto cleanup;
 	}
 	result = dns_db_findrdataset(db, node, ver, privatetype, 0,
 				     (isc_stdtime_t)0, &rdataset, NULL);
 	if (result == ISC_R_NOTFOUND) {
-		goto success;
-	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
+		result = ISC_R_SUCCESS;
+		goto cleanup;
 	}
+	CHECK(result);
 
 	for (result = dns_rdataset_first(&rdataset); result == ISC_R_SUCCESS;
 	     result = dns_rdataset_next(&rdataset))
@@ -1210,12 +1224,12 @@ try_private:
 		}
 	}
 	if (result != ISC_R_NOMORE) {
-		goto failure;
+		goto cleanup;
 	}
-success:
+
 	result = ISC_R_SUCCESS;
 
-failure:
+cleanup:
 	if (dns_rdataset_isassociated(&rdataset)) {
 		dns_rdataset_disassociate(&rdataset);
 	}
@@ -1247,7 +1261,7 @@ dns_nsec3_addnsec3sx(dns_db_t *db, dns_dbversion_t *version,
 	result = dns_db_findrdataset(db, node, version, type, 0, 0, &prdataset,
 				     NULL);
 	if (result != ISC_R_SUCCESS && result != ISC_R_NOTFOUND) {
-		goto failure;
+		CHECK(result);
 	}
 
 	result = dns_db_findrdataset(db, node, version,
@@ -1256,9 +1270,7 @@ dns_nsec3_addnsec3sx(dns_db_t *db, dns_dbversion_t *version,
 	if (result == ISC_R_NOTFOUND) {
 		goto try_private;
 	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
-	}
+	CHECK(result);
 
 	/*
 	 * Update each active NSEC3 chain.
@@ -1282,15 +1294,17 @@ dns_nsec3_addnsec3sx(dns_db_t *db, dns_dbversion_t *version,
 					 nsecttl, unsecure, diff));
 	}
 	if (result != ISC_R_NOMORE) {
-		goto failure;
+		goto cleanup;
 	}
 
 	dns_rdataset_disassociate(&rdataset);
 
 try_private:
 	if (!dns_rdataset_isassociated(&prdataset)) {
-		goto success;
+		result = ISC_R_SUCCESS;
+		goto cleanup;
 	}
+
 	/*
 	 * Update each active NSEC3 chain.
 	 */
@@ -1323,10 +1337,10 @@ try_private:
 					 nsecttl, unsecure, diff));
 	}
 	if (result == ISC_R_NOMORE) {
-	success:
 		result = ISC_R_SUCCESS;
 	}
-failure:
+
+cleanup:
 	if (dns_rdataset_isassociated(&rdataset)) {
 		dns_rdataset_disassociate(&rdataset);
 	}
@@ -1434,9 +1448,7 @@ dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version,
 	if (result == ISC_R_NOTFOUND || result == DNS_R_PARTIALMATCH) {
 		goto cleanup_orphaned_ents;
 	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
-	}
+	CHECK(result);
 
 	CHECK(dns_dbiterator_current(dbit, &node, NULL));
 	CHECK(dns_dbiterator_pause(dbit));
@@ -1446,9 +1458,7 @@ dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version,
 	if (result == ISC_R_NOTFOUND) {
 		goto cleanup_orphaned_ents;
 	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
-	}
+	CHECK(result);
 
 	/*
 	 * If we find a existing NSEC3 for this chain then save the
@@ -1462,11 +1472,9 @@ dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version,
 	}
 	dns_rdataset_disassociate(&rdataset);
 	if (result == ISC_R_NOMORE) {
-		goto success;
-	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
+		result = ISC_R_SUCCESS;
 	}
+	CHECK(result);
 
 	/*
 	 * Find the previous NSEC3 and update it.
@@ -1492,9 +1500,7 @@ dns_nsec3_delnsec3(dns_db_t *db, dns_dbversion_t *version,
 			dns_rdataset_disassociate(&rdataset);
 			continue;
 		}
-		if (result != ISC_R_SUCCESS) {
-			goto failure;
-		}
+		CHECK(result);
 
 		/*
 		 * Delete the old previous NSEC3.
@@ -1548,11 +1554,10 @@ cleanup_orphaned_ents:
 					 salt_length));
 		result = dns_dbiterator_seek(dbit, hashname);
 		if (result == ISC_R_NOTFOUND || result == DNS_R_PARTIALMATCH) {
-			goto success;
-		}
-		if (result != ISC_R_SUCCESS) {
-			goto failure;
+			result = ISC_R_SUCCESS;
+			goto cleanup;
 		}
+		CHECK(result);
 
 		CHECK(dns_dbiterator_current(dbit, &node, NULL));
 		CHECK(dns_dbiterator_pause(dbit));
@@ -1561,11 +1566,10 @@ cleanup_orphaned_ents:
 					     (isc_stdtime_t)0, &rdataset, NULL);
 		dns_db_detachnode(db, &node);
 		if (result == ISC_R_NOTFOUND) {
-			goto success;
-		}
-		if (result != ISC_R_SUCCESS) {
-			goto failure;
+			result = ISC_R_SUCCESS;
+			goto cleanup;
 		}
+		CHECK(result);
 
 		result = find_nsec3(&nsec3, &rdataset, nsec3param);
 		if (result == ISC_R_SUCCESS) {
@@ -1575,11 +1579,9 @@ cleanup_orphaned_ents:
 		}
 		dns_rdataset_disassociate(&rdataset);
 		if (result == ISC_R_NOMORE) {
-			goto success;
-		}
-		if (result != ISC_R_SUCCESS) {
-			goto failure;
+			result = ISC_R_SUCCESS;
 		}
+		CHECK(result);
 
 		pass = 0;
 		do {
@@ -1602,9 +1604,7 @@ cleanup_orphaned_ents:
 				dns_rdataset_disassociate(&rdataset);
 				continue;
 			}
-			if (result != ISC_R_SUCCESS) {
-				goto failure;
-			}
+			CHECK(result);
 
 			/*
 			 * Delete the old previous NSEC3.
@@ -1637,10 +1637,9 @@ cleanup_orphaned_ents:
 		CHECK(delnsec3(db, version, hashname, nsec3param, diff));
 	} while (1);
 
-success:
 	result = ISC_R_SUCCESS;
 
-failure:
+cleanup:
 	if (dbit != NULL) {
 		dns_dbiterator_destroy(&dbit);
 	}
@@ -1684,9 +1683,7 @@ dns_nsec3_delnsec3sx(dns_db_t *db, dns_dbversion_t *version,
 	if (result == ISC_R_NOTFOUND) {
 		goto try_private;
 	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
-	}
+	CHECK(result);
 
 	/*
 	 * Update each active NSEC3 chain.
@@ -1711,16 +1708,16 @@ dns_nsec3_delnsec3sx(dns_db_t *db, dns_dbversion_t *version,
 
 try_private:
 	if (privatetype == 0) {
-		goto success;
+		result = ISC_R_SUCCESS;
+		goto cleanup;
 	}
 	result = dns_db_findrdataset(db, node, version, privatetype, 0, 0,
 				     &rdataset, NULL);
 	if (result == ISC_R_NOTFOUND) {
-		goto success;
-	}
-	if (result != ISC_R_SUCCESS) {
-		goto failure;
+		result = ISC_R_SUCCESS;
+		goto cleanup;
 	}
+	CHECK(result);
 
 	/*
 	 * Update each NSEC3 chain being built.
@@ -1753,11 +1750,10 @@ try_private:
 		CHECK(dns_nsec3_delnsec3(db, version, name, &nsec3param, diff));
 	}
 	if (result == ISC_R_NOMORE) {
-	success:
 		result = ISC_R_SUCCESS;
 	}
 
-failure:
+cleanup:
 	if (dns_rdataset_isassociated(&rdataset)) {
 		dns_rdataset_disassociate(&rdataset);
 	}
@@ -2167,9 +2163,9 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 				*optout = ((nsec3.flags &
 					    DNS_NSEC3FLAG_OPTOUT) != 0);
 				(*logit)(arg, ISC_LOG_DEBUG(3),
-					 (*optout ? "NSEC3 indicates optout"
-						  : "NSEC3 indicates secure "
-						    "range"));
+					 *optout ? "NSEC3 indicates optout"
+						 : "NSEC3 indicates secure "
+						   "range");
 			}
 			answer = ISC_R_SUCCESS;
 		}
