@@ -52,13 +52,6 @@
 #include <dns/time.h>
 #include <dns/ttl.h>
 
-#define RETERR(x)                        \
-	do {                             \
-		isc_result_t _r = (x);   \
-		if (_r != ISC_R_SUCCESS) \
-			return ((_r));   \
-	} while (0)
-
 #define RETTOK(x)                                          \
 	do {                                               \
 		isc_result_t _r = (x);                     \
@@ -68,13 +61,6 @@
 		}                                          \
 	} while (0)
 
-#define CHECK(op)                            \
-	do {                                 \
-		result = (op);               \
-		if (result != ISC_R_SUCCESS) \
-			goto cleanup;        \
-	} while (0)
-
 #define CHECKTOK(op)                                       \
 	do {                                               \
 		result = (op);                             \
@@ -609,19 +595,26 @@ check_private(isc_buffer_t *source, dns_secalg_t alg) {
 	} else if (alg == DNS_KEYALG_PRIVATEOID) {
 		/*
 		 * Check that we can extract the OID from the start of the
-		 * key data.
+		 * key data. We have a length byte followed by the OID BER
+		 * encoded.
 		 */
 		const unsigned char *in = NULL;
 		ASN1_OBJECT *obj = NULL;
 
 		isc_buffer_activeregion(source, &sr);
-		in = sr.base;
-		obj = d2i_ASN1_OBJECT(NULL, &in, sr.length);
+		if (sr.length < 1 || (unsigned int)*sr.base + 1 > sr.length) {
+			RETERR(DNS_R_FORMERR);
+		}
+		in = sr.base + 1;
+		obj = d2i_ASN1_OBJECT(NULL, &in, *sr.base);
 		if (obj == NULL) {
 			ERR_clear_error();
 			RETERR(DNS_R_FORMERR);
 		}
 		ASN1_OBJECT_free(obj);
+		if ((in - sr.base) != (*sr.base + 1)) {
+			RETERR(DNS_R_FORMERR);
+		}
 	}
 	return ISC_R_SUCCESS;
 }
@@ -2594,7 +2587,7 @@ svcb_hashttp(isc_textregion_t *alpn) {
 				s = alpn->base;
 			}
 		}
-		if (svcb_ishttp(s, (alpn->base - s))) {
+		if (svcb_ishttp(s, alpn->base - s)) {
 			return true;
 		}
 	}
