@@ -1,16 +1,17 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
-#ifndef GENERIC_AMTRELAY_260_H
-#define GENERIC_AMTRELAY_260_H 1
+#pragma once
 
 typedef struct dns_rdata_amtrelay {
 	dns_rdatacommon_t common;
@@ -24,5 +25,3 @@ typedef struct dns_rdata_amtrelay {
 	unsigned char *data;	  /* gateway type > 3 */
 	uint16_t length;
 } dns_rdata_amtrelay_t;
-
-#endif /* GENERIC_AMTRELAY_260_H */
