@@ -498,9 +498,7 @@ tostruct_caa(ARGS_TOSTRUCT) {
 	REQUIRE(rdata->length >= 3U);
 	REQUIRE(rdata->data != NULL);
 
-	caa->common.rdclass = rdata->rdclass;
-	caa->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&caa->common, link);
+	DNS_RDATACOMMON_INIT(caa, rdata->type, rdata->rdclass);
 
 	dns_rdata_toregion(rdata, &sr);
 
