@@ -22,7 +22,7 @@
  */
 #define RRTYPE_NXT_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_nxt(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -72,7 +72,7 @@ fromtext_nxt(ARGS_FROMTEXT) {
 		 * NXT is only specified for types 1..127.
 		 */
 		if (covered < 1 || covered > 127) {
-			return (ISC_R_RANGE);
+			return ISC_R_RANGE;
 		}
 		if (first || covered > maxcovered) {
 			maxcovered = covered;
@@ -82,19 +82,18 @@ fromtext_nxt(ARGS_FROMTEXT) {
 	} while (1);
 	isc_lex_ungettoken(lexer, &token);
 	if (first) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	n = (maxcovered + 8) / 8;
-	return (mem_tobuffer(target, bm, n));
+	return mem_tobuffer(target, bm, n);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_nxt(ARGS_TOTEXT) {
 	isc_region_t sr;
-	unsigned int i, j;
+	unsigned int i, j, opts;
 	dns_name_t name;
 	dns_name_t prefix;
-	bool sub;
 
 	REQUIRE(rdata->type == dns_rdatatype_nxt);
 	REQUIRE(rdata->length != 0);
@@ -104,8 +103,9 @@ totext_nxt(ARGS_TOTEXT) {
 	dns_rdata_toregion(rdata, &sr);
 	dns_name_fromregion(&name, &sr);
 	isc_region_consume(&sr, name_length(&name));
-	sub = name_prefix(&name, tctx->origin, &prefix);
-	RETERR(dns_name_totext(&prefix, sub, target));
+	opts = name_prefix(&name, tctx->origin, &prefix) ? DNS_NAME_OMITFINALDOT
+							 : 0;
+	RETERR(dns_name_totext(&prefix, opts, target));
 
 	for (i = 0; i < sr.length; i++) {
 		if (sr.base[i] != 0) {
@@ -131,10 +131,10 @@ totext_nxt(ARGS_TOTEXT) {
 			}
 		}
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_nxt(ARGS_FROMWIRE) {
 	isc_region_t sr;
 	dns_name_t name;
@@ -144,23 +144,23 @@ fromwire_nxt(ARGS_FROMWIRE) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	dns_decompress_setmethods(dctx, DNS_COMPRESS_NONE);
+	dctx = dns_decompress_setpermitted(dctx, false);
 
 	dns_name_init(&name, NULL);
-	RETERR(dns_name_fromwire(&name, source, dctx, options, target));
+	RETERR(dns_name_fromwire(&name, source, dctx, target));
 
 	isc_buffer_activeregion(source, &sr);
 	if (sr.length > 0 && ((sr.base[0] & 0x80) != 0 || sr.length > 16 ||
 			      sr.base[sr.length - 1] == 0))
 	{
-		return (DNS_R_BADBITMAP);
+		return DNS_R_BADBITMAP;
 	}
 	RETERR(mem_tobuffer(target, sr.base, sr.length));
 	isc_buffer_forward(source, sr.length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_nxt(ARGS_TOWIRE) {
 	isc_region_t sr;
 	dns_name_t name;
@@ -169,17 +169,17 @@ towire_nxt(ARGS_TOWIRE) {
 	REQUIRE(rdata->type == dns_rdatatype_nxt);
 	REQUIRE(rdata->length != 0);
 
-	dns_compress_setmethods(cctx, DNS_COMPRESS_NONE);
+	dns_compress_setpermitted(cctx, false);
 	dns_name_init(&name, offsets);
 	dns_rdata_toregion(rdata, &sr);
 	dns_name_fromregion(&name, &sr);
 	isc_region_consume(&sr, name_length(&name));
-	RETERR(dns_name_towire(&name, cctx, target));
+	RETERR(dns_name_towire(&name, cctx, target, NULL));
 
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
-static inline int
+static int
 compare_nxt(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -201,16 +201,16 @@ compare_nxt(ARGS_COMPARE) {
 	dns_name_fromregion(&name2, &r2);
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&r1, name_length(&name1));
 	isc_region_consume(&r2, name_length(&name2));
 
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_nxt(ARGS_FROMSTRUCT) {
 	dns_rdata_nxt_t *nxt = source;
 	isc_region_t region;
@@ -231,10 +231,10 @@ fromstruct_nxt(ARGS_FROMSTRUCT) {
 	dns_name_toregion(&nxt->next, &region);
 	RETERR(isc_buffer_copyregion(target, &region));
 
-	return (mem_tobuffer(target, nxt->typebits, nxt->len));
+	return mem_tobuffer(target, nxt->typebits, nxt->len);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_nxt(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_nxt_t *nxt = target;
@@ -244,9 +244,7 @@ tostruct_nxt(ARGS_TOSTRUCT) {
 	REQUIRE(nxt != NULL);
 	REQUIRE(rdata->length != 0);
 
-	nxt->common.rdclass = rdata->rdclass;
-	nxt->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&nxt->common, link);
+	DNS_RDATACOMMON_INIT(nxt, rdata->type, rdata->rdclass);
 
 	dns_name_init(&name, NULL);
 	dns_rdata_toregion(rdata, &region);
@@ -257,21 +255,11 @@ tostruct_nxt(ARGS_TOSTRUCT) {
 
 	nxt->len = region.length;
 	nxt->typebits = mem_maybedup(mctx, region.base, region.length);
-	if (nxt->typebits == NULL) {
-		goto cleanup;
-	}
-
 	nxt->mctx = mctx;
-	return (ISC_R_SUCCESS);
-
-cleanup:
-	if (mctx != NULL) {
-		dns_name_free(&nxt->next, mctx);
-	}
-	return (ISC_R_NOMEMORY);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_nxt(ARGS_FREESTRUCT) {
 	dns_rdata_nxt_t *nxt = source;
 
@@ -289,7 +277,7 @@ freestruct_nxt(ARGS_FREESTRUCT) {
 	nxt->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_nxt(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_nxt);
 
@@ -298,10 +286,10 @@ additionaldata_nxt(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_nxt(ARGS_DIGEST) {
 	isc_region_t r;
 	dns_name_t name;
@@ -314,14 +302,14 @@ digest_nxt(ARGS_DIGEST) {
 	dns_name_fromregion(&name, &r);
 	result = dns_name_digest(&name, digest, arg);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	isc_region_consume(&r, name_length(&name));
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_nxt(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_nxt);
 
@@ -330,10 +318,10 @@ checkowner_nxt(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_nxt(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_nxt);
 
@@ -341,11 +329,11 @@ checknames_nxt(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_nxt(ARGS_COMPARE) {
-	return (compare_nxt(rdata1, rdata2));
+	return compare_nxt(rdata1, rdata2);
 }
 #endif /* RDATA_GENERIC_NXT_30_C */
