@@ -1,6 +1,8 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -9,8 +11,7 @@
  * information regarding copyright ownership.
  */
 
-#ifndef GENERIC_RP_17_H
-#define GENERIC_RP_17_H 1
+#pragma once
 
 /*!
  *  \brief Per RFC1183 */
@@ -21,5 +22,3 @@ typedef struct dns_rdata_rp {
 	dns_name_t mail;
 	dns_name_t text;
 } dns_rdata_rp_t;
-
-#endif /* GENERIC_RP_17_H */
