@@ -18,7 +18,7 @@
 
 #define RRTYPE_RT_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_rt(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -57,15 +57,15 @@ fromtext_rt(ARGS_FROMTEXT) {
 	if (!ok && callbacks != NULL) {
 		warn_badname(&name, lexer, callbacks);
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_rt(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
 	dns_name_t prefix;
-	bool sub;
+	unsigned int opts;
 	char buf[sizeof("64000")];
 	unsigned short num;
 
@@ -82,11 +82,12 @@ totext_rt(ARGS_TOTEXT) {
 	RETERR(str_totext(buf, target));
 	RETERR(str_totext(" ", target));
 	dns_name_fromregion(&name, &region);
-	sub = name_prefix(&name, tctx->origin, &prefix);
-	return (dns_name_totext(&prefix, sub, target));
+	opts = name_prefix(&name, tctx->origin, &prefix) ? DNS_NAME_OMITFINALDOT
+							 : 0;
+	return dns_name_totext(&prefix, opts, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_rt(ARGS_FROMWIRE) {
 	dns_name_t name;
 	isc_region_t sregion;
@@ -97,25 +98,25 @@ fromwire_rt(ARGS_FROMWIRE) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	dns_decompress_setmethods(dctx, DNS_COMPRESS_NONE);
+	dctx = dns_decompress_setpermitted(dctx, false);
 
 	dns_name_init(&name, NULL);
 
 	isc_buffer_activeregion(source, &sregion);
 	isc_buffer_availableregion(target, &tregion);
 	if (tregion.length < 2) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	if (sregion.length < 2) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	memmove(tregion.base, sregion.base, 2);
 	isc_buffer_forward(source, 2);
 	isc_buffer_add(target, 2);
-	return (dns_name_fromwire(&name, source, dctx, options, target));
+	return dns_name_fromwire(&name, source, dctx, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_rt(ARGS_TOWIRE) {
 	dns_name_t name;
 	dns_offsets_t offsets;
@@ -125,11 +126,11 @@ towire_rt(ARGS_TOWIRE) {
 	REQUIRE(rdata->type == dns_rdatatype_rt);
 	REQUIRE(rdata->length != 0);
 
-	dns_compress_setmethods(cctx, DNS_COMPRESS_NONE);
+	dns_compress_setpermitted(cctx, false);
 	isc_buffer_availableregion(target, &tr);
 	dns_rdata_toregion(rdata, &region);
 	if (tr.length < 2) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	memmove(tr.base, region.base, 2);
 	isc_region_consume(&region, 2);
@@ -138,10 +139,10 @@ towire_rt(ARGS_TOWIRE) {
 	dns_name_init(&name, offsets);
 	dns_name_fromregion(&name, &region);
 
-	return (dns_name_towire(&name, cctx, target));
+	return dns_name_towire(&name, cctx, target, NULL);
 }
 
-static inline int
+static int
 compare_rt(ARGS_COMPARE) {
 	dns_name_t name1;
 	dns_name_t name2;
@@ -157,7 +158,7 @@ compare_rt(ARGS_COMPARE) {
 
 	order = memcmp(rdata1->data, rdata2->data, 2);
 	if (order != 0) {
-		return (order < 0 ? -1 : 1);
+		return order < 0 ? -1 : 1;
 	}
 
 	dns_name_init(&name1, NULL);
@@ -172,10 +173,10 @@ compare_rt(ARGS_COMPARE) {
 	dns_name_fromregion(&name1, &region1);
 	dns_name_fromregion(&name2, &region2);
 
-	return (dns_name_rdatacompare(&name1, &name2));
+	return dns_name_rdatacompare(&name1, &name2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_rt(ARGS_FROMSTRUCT) {
 	dns_rdata_rt_t *rt = source;
 	isc_region_t region;
@@ -190,10 +191,10 @@ fromstruct_rt(ARGS_FROMSTRUCT) {
 
 	RETERR(uint16_tobuffer(rt->preference, target));
 	dns_name_toregion(&rt->host, &region);
-	return (isc_buffer_copyregion(target, &region));
+	return isc_buffer_copyregion(target, &region);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_rt(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_rt_t *rt = target;
@@ -203,9 +204,7 @@ tostruct_rt(ARGS_TOSTRUCT) {
 	REQUIRE(rt != NULL);
 	REQUIRE(rdata->length != 0);
 
-	rt->common.rdclass = rdata->rdclass;
-	rt->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&rt->common, link);
+	DNS_RDATACOMMON_INIT(rt, rdata->type, rdata->rdclass);
 
 	dns_name_init(&name, NULL);
 	dns_rdata_toregion(rdata, &region);
@@ -216,10 +215,10 @@ tostruct_rt(ARGS_TOSTRUCT) {
 	name_duporclone(&name, mctx, &rt->host);
 
 	rt->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_rt(ARGS_FREESTRUCT) {
 	dns_rdata_rt_t *rt = source;
 
@@ -234,7 +233,7 @@ freestruct_rt(ARGS_FREESTRUCT) {
 	rt->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_rt(ARGS_ADDLDATA) {
 	dns_name_t name;
 	dns_offsets_t offsets;
@@ -250,18 +249,18 @@ additionaldata_rt(ARGS_ADDLDATA) {
 	isc_region_consume(&region, 2);
 	dns_name_fromregion(&name, &region);
 
-	result = (add)(arg, &name, dns_rdatatype_x25, NULL);
+	result = (add)(arg, &name, dns_rdatatype_x25, NULL DNS__DB_FILELINE);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
-	result = (add)(arg, &name, dns_rdatatype_isdn, NULL);
+	result = (add)(arg, &name, dns_rdatatype_isdn, NULL DNS__DB_FILELINE);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
-	return ((add)(arg, &name, dns_rdatatype_a, NULL));
+	return (add)(arg, &name, dns_rdatatype_a, NULL DNS__DB_FILELINE);
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_rt(ARGS_DIGEST) {
 	isc_region_t r1, r2;
 	isc_result_t result;
@@ -275,14 +274,14 @@ digest_rt(ARGS_DIGEST) {
 	r1.length = 2;
 	result = (digest)(arg, &r1);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &r2);
-	return (dns_name_digest(&name, digest, arg));
+	return dns_name_digest(&name, digest, arg);
 }
 
-static inline bool
+static bool
 checkowner_rt(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_rt);
 
@@ -291,10 +290,10 @@ checkowner_rt(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_rt(ARGS_CHECKNAMES) {
 	isc_region_t region;
 	dns_name_t name;
@@ -311,14 +310,14 @@ checknames_rt(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_rt(ARGS_COMPARE) {
-	return (compare_rt(rdata1, rdata2));
+	return compare_rt(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_RT_21_C */
