@@ -66,7 +66,6 @@ fromwire_in_eid(ARGS_FROMWIRE) {
 
 	UNUSED(type);
 	UNUSED(dctx);
-	UNUSED(options);
 	UNUSED(rdclass);
 
 	isc_buffer_activeregion(source, &region);
@@ -134,17 +133,11 @@ tostruct_in_eid(ARGS_TOSTRUCT) {
 	REQUIRE(eid != NULL);
 	REQUIRE(rdata->length != 0);
 
-	eid->common.rdclass = rdata->rdclass;
-	eid->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&eid->common, link);
+	DNS_RDATACOMMON_INIT(eid, rdata->type, rdata->rdclass);
 
 	dns_rdata_toregion(rdata, &r);
 	eid->eid_len = r.length;
 	eid->eid = mem_maybedup(mctx, r.base, r.length);
-	if (eid->eid == NULL) {
-		return ISC_R_NOMEMORY;
-	}
-
 	eid->mctx = mctx;
 	return ISC_R_SUCCESS;
 }
