@@ -25,7 +25,7 @@
 #include <isc/mem.h>
 #include <isc/net.h>
 #include <isc/netaddr.h>
-#include <isc/print.h>
+#include <isc/overflow.h>
 #include <isc/result.h>
 #include <isc/util.h>
 
@@ -238,9 +238,8 @@ expand_entries(dns_rrl_t *rrl, int newsize) {
 	}
 
 	bsize = sizeof(dns_rrl_block_t) +
-		(newsize - 1) * sizeof(dns_rrl_entry_t);
-	b = isc_mem_get(rrl->mctx, bsize);
-	memset(b, 0, bsize);
+		ISC_CHECKED_MUL(newsize - 1, sizeof(dns_rrl_entry_t));
+	b = isc_mem_cget(rrl->mctx, 1, bsize);
 	b->size = bsize;
 
 	e = b->entries;
@@ -278,7 +277,8 @@ free_old_hash(dns_rrl_t *rrl) {
 
 	isc_mem_put(rrl->mctx, old_hash,
 		    sizeof(*old_hash) +
-			    (old_hash->length - 1) * sizeof(old_hash->bins[0]));
+			    ISC_CHECKED_MUL(old_hash->length - 1,
+					    sizeof(old_hash->bins[0])));
 	rrl->old_hash = NULL;
 }
 
@@ -303,9 +303,9 @@ expand_rrl_hash(dns_rrl_t *rrl, isc_stdtime_t now) {
 	}
 	new_bins = hash_divisor(new_bins);
 
-	hsize = sizeof(dns_rrl_hash_t) + (new_bins - 1) * sizeof(hash->bins[0]);
-	hash = isc_mem_get(rrl->mctx, hsize);
-	memset(hash, 0, hsize);
+	hsize = sizeof(dns_rrl_hash_t) +
+		ISC_CHECKED_MUL(new_bins - 1, sizeof(hash->bins[0]));
+	hash = isc_mem_cget(rrl->mctx, 1, hsize);
 	hash->length = new_bins;
 	rrl->hash_gen ^= 1;
 	hash->gen = rrl->hash_gen;
@@ -419,8 +419,8 @@ make_key(const dns_rrl_t *rrl, dns_rrl_key_t *key,
 	if (qname != NULL && qname->labels != 0) {
 		dns_name_t *origin = NULL;
 
-		if ((qname->attributes & DNS_NAMEATTR_WILDCARD) != 0 &&
-		    zone != NULL && (origin = dns_zone_getorigin(zone)) != NULL)
+		if (qname->attributes.wildcard && zone != NULL &&
+		    (origin = dns_zone_getorigin(zone)) != NULL)
 		{
 			dns_fixedname_t fixed;
 			dns_name_t *wild;
@@ -440,9 +440,9 @@ make_key(const dns_rrl_t *rrl, dns_rrl_key_t *key,
 				 */
 				wild = origin;
 			}
-			key->s.qname_hash = dns_name_fullhash(wild, false);
+			key->s.qname_hash = dns_name_hash(wild);
 		} else {
-			key->s.qname_hash = dns_name_fullhash(qname, false);
+			key->s.qname_hash = dns_name_hash(qname);
 		}
 	}
 
@@ -918,12 +918,11 @@ make_log_buf(dns_rrl_t *rrl, dns_rrl_entry_t *e, const char *str1,
 				ISC_LIST_UNLINK(rrl->qname_free, qbuf, link);
 			} else if (rrl->num_qnames < DNS_RRL_QNAMES) {
 				qbuf = isc_mem_get(rrl->mctx, sizeof(*qbuf));
-				{
-					memset(qbuf, 0, sizeof(*qbuf));
-					ISC_LINK_INIT(qbuf, link);
-					qbuf->index = rrl->num_qnames;
-					rrl->qnames[rrl->num_qnames++] = qbuf;
-				}
+				*qbuf = (dns_rrl_qname_buf_t){
+					.index = rrl->num_qnames,
+				};
+				ISC_LINK_INIT(qbuf, link);
+				rrl->qnames[rrl->num_qnames++] = qbuf;
 			}
 			if (qbuf != NULL) {
 				e->log_qname = qbuf->index;
@@ -938,7 +937,8 @@ make_log_buf(dns_rrl_t *rrl, dns_rrl_entry_t *e, const char *str1,
 		}
 		if (qname != NULL) {
 			ADD_LOG_CSTR(&lb, " for ");
-			(void)dns_name_totext(qname, true, &lb);
+			(void)dns_name_totext(qname, DNS_NAME_OMITFINALDOT,
+					      &lb);
 		} else {
 			ADD_LOG_CSTR(&lb, " for (?)");
 		}
@@ -1302,13 +1302,15 @@ dns_rrl_view_destroy(dns_view_t *view) {
 	h = rrl->hash;
 	if (h != NULL) {
 		isc_mem_put(rrl->mctx, h,
-			    sizeof(*h) + (h->length - 1) * sizeof(h->bins[0]));
+			    sizeof(*h) + ISC_CHECKED_MUL(h->length - 1,
+							 sizeof(h->bins[0])));
 	}
 
 	h = rrl->old_hash;
 	if (h != NULL) {
 		isc_mem_put(rrl->mctx, h,
-			    sizeof(*h) + (h->length - 1) * sizeof(h->bins[0]));
+			    sizeof(*h) + ISC_CHECKED_MUL(h->length - 1,
+							 sizeof(h->bins[0])));
 	}
 
 	isc_mem_putanddetach(&rrl->mctx, rrl, sizeof(*rrl));
@@ -1322,10 +1324,11 @@ dns_rrl_init(dns_rrl_t **rrlp, dns_view_t *view, int min_entries) {
 	*rrlp = NULL;
 
 	rrl = isc_mem_get(view->mctx, sizeof(*rrl));
-	memset(rrl, 0, sizeof(*rrl));
+	*rrl = (dns_rrl_t){
+		.ts_bases[0] = isc_stdtime_now(),
+	};
 	isc_mem_attach(view->mctx, &rrl->mctx);
 	isc_mutex_init(&rrl->lock);
-	isc_stdtime_get(&rrl->ts_bases[0]);
 
 	view->rrl = rrl;
 
