@@ -17,7 +17,6 @@
 #include <isc/formatcheck.h>
 #include <isc/mem.h>
 #include <isc/netmgr.h>
-#include <isc/print.h>
 #include <isc/result.h>
 #include <isc/stats.h>
 #include <isc/util.h>
@@ -103,7 +102,7 @@
 
 static void
 inc_stats(ns_client_t *client, dns_zone_t *zone, isc_statscounter_t counter) {
-	ns_stats_increment(client->sctx->nsstats, counter);
+	ns_stats_increment(client->manager->sctx->nsstats, counter);
 	if (zone != NULL) {
 		isc_stats_t *zonestats = dns_zone_getrequeststats(zone);
 		if (zonestats != NULL) {
@@ -140,7 +139,7 @@ log_rr(dns_name_t *name, dns_rdata_t *rdata, uint32_t ttl) {
 	dns_rdata_init(&rd);
 	dns_rdata_clone(rdata, &rd);
 	ISC_LIST_APPEND(rdl.rdata, &rd, link);
-	RUNTIME_CHECK(dns_rdatalist_tordataset(&rdl, &rds) == ISC_R_SUCCESS);
+	dns_rdatalist_tordataset(&rdl, &rds);
 
 	isc_buffer_init(&buf, mem, sizeof(mem));
 	result = dns_rdataset_totext(&rds, name, false, false, &buf);
@@ -643,7 +642,6 @@ typedef struct {
 	dns_zone_t *zone; /* (necessary for stats) */
 	dns_db_t *db;
 	dns_dbversion_t *ver;
-	isc_quota_t *quota;
 	rrstream_t *stream;  /* The XFR RR stream */
 	bool question_added; /* QUESTION section sent? */
 	bool end_of_stream;  /* EOS has been reached */
@@ -669,13 +667,16 @@ typedef struct {
 	isc_nm_timer_t *maxtime_timer;
 
 	uint64_t idletime; /*%< XFR idle timeout (in ms) */
+
+	/* Delayed send */
+	isc_nm_timer_t *delayed_send_timer;
 } xfrout_ctx_t;
 
 static void
 xfrout_ctx_create(isc_mem_t *mctx, ns_client_t *client, unsigned int id,
 		  dns_name_t *qname, dns_rdatatype_t qtype,
 		  dns_rdataclass_t qclass, dns_zone_t *zone, dns_db_t *db,
-		  dns_dbversion_t *ver, isc_quota_t *quota, rrstream_t *stream,
+		  dns_dbversion_t *ver, rrstream_t *stream,
 		  dns_tsigkey_t *tsigkey, isc_buffer_t *lasttsig,
 		  bool verified_tsig, unsigned int maxtime,
 		  unsigned int idletime, bool many_answers,
@@ -707,6 +708,9 @@ static void
 xfrout_log(xfrout_ctx_t *xfr, int level, const char *fmt, ...)
 	ISC_FORMAT_PRINTF(3, 4);
 
+static void
+xfrout_delayed_timeout(void *arg, isc_result_t result);
+
 /**************************************************************************/
 
 void
@@ -727,10 +731,9 @@ ns_xfr_start(ns_client_t *client, dns_rdatatype_t reqtype) {
 	dns_rdata_t soa_rdata = DNS_RDATA_INIT;
 	bool have_soa = false;
 	const char *mnemonic = NULL;
-	isc_mem_t *mctx = client->mctx;
+	isc_mem_t *mctx = client->manager->mctx;
 	dns_message_t *request = client->message;
 	xfrout_ctx_t *xfr = NULL;
-	isc_quota_t *quota = NULL;
 	dns_transfer_format_t format = client->view->transfer_format;
 	isc_netaddr_t na;
 	dns_peer_t *peer = NULL;
@@ -760,12 +763,12 @@ ns_xfr_start(ns_client_t *client, dns_rdatatype_t reqtype) {
 	/*
 	 * Apply quota.
 	 */
-	result = isc_quota_attach(&client->sctx->xfroutquota, &quota);
+	result = isc_quota_acquire(&client->manager->sctx->xfroutquota);
 	if (result != ISC_R_SUCCESS) {
 		isc_log_write(XFROUT_COMMON_LOGARGS, ISC_LOG_WARNING,
 			      "%s request denied: %s", mnemonic,
 			      isc_result_totext(result));
-		goto cleanup;
+		goto max_quota;
 	}
 
 	/*
@@ -791,9 +794,8 @@ ns_xfr_start(ns_client_t *client, dns_rdatatype_t reqtype) {
 		FAILC(DNS_R_FORMERR, "multiple questions");
 	}
 
-	result = dns_zt_find(client->view->zonetable, question_name, 0, NULL,
-			     &zone);
-
+	result = dns_view_findzone(client->view, question_name,
+				   DNS_ZTFIND_EXACT, &zone);
 	if (result != ISC_R_SUCCESS || dns_zone_gettype(zone) == dns_zone_dlz) {
 		/*
 		 * The normal zone table does not have a match, or this is
@@ -1025,7 +1027,8 @@ got_soa:
 			xfrout_log1(client, question_name, question_class,
 				    ISC_LOG_INFO,
 				    "IXFR version not in journal, "
-				    "falling back to AXFR");
+				    "falling back to AXFR (serial %u)",
+				    begin_serial);
 			mnemonic = "AXFR-style IXFR";
 			goto axfr_fallback;
 		}
@@ -1080,7 +1083,7 @@ have_stream:
 
 	if (is_dlz) {
 		xfrout_ctx_create(mctx, client, request->id, question_name,
-				  reqtype, question_class, zone, db, ver, quota,
+				  reqtype, question_class, zone, db, ver,
 				  stream, dns_message_gettsigkey(request),
 				  tsigbuf, request->verified_sig, 3600, 3600,
 				  (format == dns_many_answers) ? true : false,
@@ -1088,7 +1091,7 @@ have_stream:
 	} else {
 		xfrout_ctx_create(
 			mctx, client, request->id, question_name, reqtype,
-			question_class, zone, db, ver, quota, stream,
+			question_class, zone, db, ver, stream,
 			dns_message_gettsigkey(request), tsigbuf,
 			request->verified_sig, dns_zone_getmaxxfrout(zone),
 			dns_zone_getidleout(zone),
@@ -1098,12 +1101,11 @@ have_stream:
 	xfr->end_serial = current_serial;
 	xfr->mnemonic = mnemonic;
 	stream = NULL;
-	quota = NULL;
 
 	CHECK(xfr->stream->methods->first(xfr->stream));
 
 	if (xfr->tsigkey != NULL) {
-		dns_name_format(&xfr->tsigkey->name, keyname, sizeof(keyname));
+		dns_name_format(xfr->tsigkey->name, keyname, sizeof(keyname));
 	} else {
 		keyname[0] = '\0';
 	}
@@ -1168,9 +1170,6 @@ cleanup:
 	if (result == DNS_R_REFUSED) {
 		inc_stats(client, zone, ns_statscounter_xfrrej);
 	}
-	if (quota != NULL) {
-		isc_quota_detach(&quota);
-	}
 	if (current_soa_tuple != NULL) {
 		dns_difftuple_free(&current_soa_tuple);
 	}
@@ -1192,10 +1191,12 @@ cleanup:
 	if (zone != NULL) {
 		dns_zone_detach(&zone);
 	}
-	/* XXX kludge */
+
 	if (xfr != NULL) {
 		xfrout_fail(xfr, result, "setting up zone transfer");
 	} else if (result != ISC_R_SUCCESS) {
+		isc_quota_release(&client->manager->sctx->xfroutquota);
+	max_quota:
 		ns_client_log(client, DNS_LOGCATEGORY_XFER_OUT,
 			      NS_LOGMODULE_XFER_OUT, ISC_LOG_DEBUG(3),
 			      "zone transfer setup failed");
@@ -1208,7 +1209,7 @@ static void
 xfrout_ctx_create(isc_mem_t *mctx, ns_client_t *client, unsigned int id,
 		  dns_name_t *qname, dns_rdatatype_t qtype,
 		  dns_rdataclass_t qclass, dns_zone_t *zone, dns_db_t *db,
-		  dns_dbversion_t *ver, isc_quota_t *quota, rrstream_t *stream,
+		  dns_dbversion_t *ver, rrstream_t *stream,
 		  dns_tsigkey_t *tsigkey, isc_buffer_t *lasttsig,
 		  bool verified_tsig, unsigned int maxtime,
 		  unsigned int idletime, bool many_answers,
@@ -1242,11 +1243,14 @@ xfrout_ctx_create(isc_mem_t *mctx, ns_client_t *client, unsigned int id,
 	dns_db_attach(db, &xfr->db);
 	dns_db_attachversion(db, ver, &xfr->ver);
 
-	isc_time_now(&xfr->stats.start);
+	xfr->stats.start = isc_time_now();
 
 	isc_nm_timer_create(xfr->client->handle, xfrout_client_timeout, xfr,
 			    &xfr->maxtime_timer);
 
+	isc_nm_timer_create(xfr->client->handle, xfrout_delayed_timeout, xfr,
+			    &xfr->delayed_send_timer);
+
 	/*
 	 * Allocate a temporary buffer for the uncompressed response
 	 * message data.  The buffer size must be 65535 bytes
@@ -1275,12 +1279,79 @@ xfrout_ctx_create(isc_mem_t *mctx, ns_client_t *client, unsigned int id,
 	 * These MUST be after the last "goto cleanup;" / CHECK to
 	 * prevent a double free by the caller.
 	 */
-	xfr->quota = quota;
 	xfr->stream = stream;
 
 	*xfrp = xfr;
 }
 
+static void
+xfrout_send(xfrout_ctx_t *xfr) {
+	const bool is_tcp = ((xfr->client->attributes & NS_CLIENTATTR_TCP) !=
+			     0);
+
+	if (is_tcp) {
+		isc_region_t used;
+
+		isc_buffer_usedregion(&xfr->txbuf, &used);
+
+		isc_nmhandle_attach(xfr->client->handle,
+				    &xfr->client->sendhandle);
+		if (xfr->idletime > 0) {
+			isc_nmhandle_setwritetimeout(xfr->client->sendhandle,
+						     xfr->idletime);
+		}
+		isc_nm_send(xfr->client->sendhandle, &used, xfrout_senddone,
+			    xfr);
+		xfr->sends++;
+		xfr->cbytes = used.length;
+	} else {
+		ns_client_send(xfr->client);
+		xfr->stream->methods->pause(xfr->stream);
+		isc_nmhandle_detach(&xfr->client->reqhandle);
+		xfrout_ctx_destroy(&xfr);
+	}
+}
+
+static void
+xfrout_delayed_timeout(void *arg, isc_result_t result) {
+	xfrout_ctx_t *xfr = (xfrout_ctx_t *)arg;
+	UNUSED(result);
+
+	isc_nm_timer_stop(xfr->delayed_send_timer);
+	xfrout_send(xfr);
+}
+
+static void
+xfrout_enqueue_send(xfrout_ctx_t *xfr) {
+	uint64_t timeout = 0;
+
+	/*
+	 * System test helper options to simulate network issues.
+	 *
+	 * Both "transferslowly" and "transferstuck" are not meant to be
+	 * used together (and are not actually used this way).
+	 */
+	if (ns_server_getoption(xfr->client->manager->sctx,
+				NS_SERVER_TRANSFERSLOWLY))
+	{
+		/* Sleep for a bit over a second. */
+		timeout = 1000;
+	} else if (ns_server_getoption(xfr->client->manager->sctx,
+				       NS_SERVER_TRANSFERSTUCK))
+	{
+		/* Sleep for a bit over a minute. */
+		timeout = 60 * 1000;
+	}
+
+	if (timeout == 0) {
+		xfrout_send(xfr);
+		return;
+	}
+
+	/* delay */
+	isc_nm_timer_start(xfr->delayed_send_timer, timeout);
+}
+
 /*
  * Arrange to send as much as we can of "stream" without blocking.
  *
@@ -1324,8 +1395,8 @@ sendstream(xfrout_ctx_t *xfr) {
 		 * message.
 		 */
 
-		dns_message_create(xfr->mctx, DNS_MESSAGE_INTENTRENDER,
-				   &tcpmsg);
+		dns_message_create(xfr->mctx, NULL, NULL,
+				   DNS_MESSAGE_INTENTRENDER, &tcpmsg);
 		msg = tcpmsg;
 
 		msg->id = xfr->id;
@@ -1335,7 +1406,7 @@ sendstream(xfrout_ctx_t *xfr) {
 			msg->flags |= DNS_MESSAGEFLAG_RA;
 		}
 		CHECK(dns_message_settsigkey(msg, xfr->tsigkey));
-		CHECK(dns_message_setquerytsig(msg, xfr->lasttsig));
+		dns_message_setquerytsig(msg, xfr->lasttsig);
 		if (xfr->lasttsig != NULL) {
 			isc_buffer_free(&xfr->lasttsig);
 		}
@@ -1380,12 +1451,12 @@ sendstream(xfrout_ctx_t *xfr) {
 			isc_buffer_add(&xfr->buf, 12 + 4);
 
 			qrdataset = NULL;
-			CHECK(dns_message_gettemprdataset(msg, &qrdataset));
+			dns_message_gettemprdataset(msg, &qrdataset);
 			dns_rdataset_makequestion(qrdataset,
 						  xfr->client->message->rdclass,
 						  xfr->qtype);
 
-			CHECK(dns_message_gettempname(msg, &qname));
+			dns_message_gettempname(msg, &qname);
 			isc_buffer_availableregion(&xfr->buf, &r);
 			INSIST(r.length >= xfr->qname->length);
 			r.length = xfr->qname->length;
@@ -1454,7 +1525,7 @@ sendstream(xfrout_ctx_t *xfr) {
 			log_rr(name, rdata, ttl); /* XXX */
 		}
 
-		CHECK(dns_message_gettempname(msg, &msgname));
+		dns_message_gettempname(msg, &msgname);
 		isc_buffer_availableregion(&xfr->buf, &r);
 		INSIST(r.length >= name->length);
 		r.length = name->length;
@@ -1464,14 +1535,14 @@ sendstream(xfrout_ctx_t *xfr) {
 		/* Reserve space for RR header. */
 		isc_buffer_add(&xfr->buf, 10);
 
-		CHECK(dns_message_gettemprdata(msg, &msgrdata));
+		dns_message_gettemprdata(msg, &msgrdata);
 		isc_buffer_availableregion(&xfr->buf, &r);
 		r.length = rdata->length;
 		isc_buffer_putmem(&xfr->buf, rdata->data, rdata->length);
 		dns_rdata_init(msgrdata);
 		dns_rdata_fromregion(msgrdata, rdata->rdclass, rdata->type, &r);
 
-		CHECK(dns_message_gettemprdatalist(msg, &msgrdl));
+		dns_message_gettemprdatalist(msg, &msgrdl);
 		msgrdl->type = rdata->type;
 		msgrdl->rdclass = rdata->rdclass;
 		msgrdl->ttl = ttl;
@@ -1484,9 +1555,8 @@ sendstream(xfrout_ctx_t *xfr) {
 		}
 		ISC_LIST_APPEND(msgrdl->rdata, msgrdata, link);
 
-		CHECK(dns_message_gettemprdataset(msg, &msgrds));
-		result = dns_rdatalist_tordataset(msgrdl, msgrds);
-		INSIST(result == ISC_R_SUCCESS);
+		dns_message_gettemprdataset(msg, &msgrds);
+		dns_rdatalist_tordataset(msgrdl, msgrds);
 
 		ISC_LIST_APPEND(msgname->list, msgrds, link);
 
@@ -1511,7 +1581,7 @@ sendstream(xfrout_ctx_t *xfr) {
 		 * here (TCP only).
 		 */
 		if ((isc_buffer_usedlength(&xfr->buf) >=
-		     xfr->client->sctx->transfer_tcp_message_size) &&
+		     xfr->client->manager->sctx->transfer_tcp_message_size) &&
 		    is_tcp)
 		{
 			break;
@@ -1519,9 +1589,8 @@ sendstream(xfrout_ctx_t *xfr) {
 	}
 
 	if (is_tcp) {
-		isc_region_t used;
-		CHECK(dns_compress_init(&cctx, -1, xfr->mctx));
-		dns_compress_setsensitive(&cctx, true);
+		dns_compress_init(&cctx, xfr->mctx,
+				  DNS_COMPRESS_CASE | DNS_COMPRESS_LARGE);
 		cleanup_cctx = true;
 		CHECK(dns_message_renderbegin(msg, &cctx, &xfr->txbuf));
 		CHECK(dns_message_rendersection(msg, DNS_SECTION_QUESTION, 0));
@@ -1530,60 +1599,15 @@ sendstream(xfrout_ctx_t *xfr) {
 		dns_compress_invalidate(&cctx);
 		cleanup_cctx = false;
 
-		isc_buffer_usedregion(&xfr->txbuf, &used);
-
 		xfrout_log(xfr, ISC_LOG_DEBUG(8),
-			   "sending TCP message of %d bytes", used.length);
+			   "sending TCP message of %d bytes",
+			   isc_buffer_usedlength(&xfr->txbuf));
 
-		/* System test helper options to simulate network issues. */
-		if (ns_server_getoption(xfr->client->manager->sctx,
-					NS_SERVER_TRANSFERSLOWLY))
-		{
-			/* Sleep for a bit over a second. */
-			select(0, NULL, NULL, NULL,
-			       &(struct timeval){ 1, 1000 });
-		}
-		if (ns_server_getoption(xfr->client->manager->sctx,
-					NS_SERVER_TRANSFERSTUCK))
-		{
-			/* Sleep for a bit over a minute. */
-			select(0, NULL, NULL, NULL,
-			       &(struct timeval){ 60, 1000 });
-		}
-
-		isc_nmhandle_attach(xfr->client->handle,
-				    &xfr->client->sendhandle);
-		if (xfr->idletime > 0) {
-			isc_nmhandle_setwritetimeout(xfr->client->sendhandle,
-						     xfr->idletime);
-		}
-		isc_nm_send(xfr->client->sendhandle, &used, xfrout_senddone,
-			    xfr);
-		xfr->sends++;
-		xfr->cbytes = used.length;
+		xfrout_enqueue_send(xfr);
 	} else {
 		xfrout_log(xfr, ISC_LOG_DEBUG(8), "sending IXFR UDP response");
 
-		/* System test helper options to simulate network issues. */
-		if (ns_server_getoption(xfr->client->manager->sctx,
-					NS_SERVER_TRANSFERSLOWLY))
-		{
-			/* Sleep for a bit over a second. */
-			select(0, NULL, NULL, NULL,
-			       &(struct timeval){ 1, 1000 });
-		}
-		if (ns_server_getoption(xfr->client->manager->sctx,
-					NS_SERVER_TRANSFERSTUCK))
-		{
-			/* Sleep for a bit over a minute. */
-			select(0, NULL, NULL, NULL,
-			       &(struct timeval){ 60, 1000 });
-		}
-
-		ns_client_send(xfr->client);
-		xfr->stream->methods->pause(xfr->stream);
-		isc_nmhandle_detach(&xfr->client->reqhandle);
-		xfrout_ctx_destroy(&xfr);
+		xfrout_enqueue_send(xfr);
 		return;
 	}
 
@@ -1591,23 +1615,6 @@ sendstream(xfrout_ctx_t *xfr) {
 	CHECK(dns_message_getquerytsig(msg, xfr->mctx, &xfr->lasttsig));
 
 cleanup:
-	if (msgname != NULL) {
-		if (msgrds != NULL) {
-			if (dns_rdataset_isassociated(msgrds)) {
-				dns_rdataset_disassociate(msgrds);
-			}
-			dns_message_puttemprdataset(msg, &msgrds);
-		}
-		if (msgrdl != NULL) {
-			ISC_LIST_UNLINK(msgrdl->rdata, msgrdata, link);
-			dns_message_puttemprdatalist(msg, &msgrdl);
-		}
-		if (msgrdata != NULL) {
-			dns_message_puttemprdata(msg, &msgrdata);
-		}
-		dns_message_puttempname(msg, &msgname);
-	}
-
 	if (tcpmsg != NULL) {
 		dns_message_detach(&tcpmsg);
 	}
@@ -1625,10 +1632,6 @@ cleanup:
 		return;
 	}
 
-	if (xfr->client->sendhandle != NULL) {
-		isc_nmhandle_detach(&xfr->client->sendhandle);
-	}
-
 	xfrout_fail(xfr, result, "sending zone data");
 }
 
@@ -1639,6 +1642,9 @@ xfrout_ctx_destroy(xfrout_ctx_t **xfrp) {
 
 	INSIST(xfr->sends == 0);
 
+	isc_nm_timer_stop(xfr->delayed_send_timer);
+	isc_nm_timer_detach(&xfr->delayed_send_timer);
+
 	isc_nm_timer_stop(xfr->maxtime_timer);
 	isc_nm_timer_detach(&xfr->maxtime_timer);
 
@@ -1654,9 +1660,9 @@ xfrout_ctx_destroy(xfrout_ctx_t **xfrp) {
 	if (xfr->lasttsig != NULL) {
 		isc_buffer_free(&xfr->lasttsig);
 	}
-	if (xfr->quota != NULL) {
-		isc_quota_detach(&xfr->quota);
-	}
+
+	isc_quota_release(&xfr->client->manager->sctx->xfroutquota);
+
 	if (xfr->ver != NULL) {
 		dns_db_closeversion(xfr->db, &xfr->ver, false);
 	}
@@ -1703,7 +1709,7 @@ xfrout_senddone(isc_nmhandle_t *handle, isc_result_t result, void *arg) {
 		uint64_t msecs, persec;
 
 		inc_stats(xfr->client, xfr->zone, ns_statscounter_xfrdone);
-		isc_time_now(&xfr->stats.end);
+		xfr->stats.end = isc_time_now();
 		msecs = isc_time_microdiff(&xfr->stats.end, &xfr->stats.start);
 		msecs /= 1000;
 		if (msecs == 0) {
