@@ -80,10 +80,10 @@ setup_test(void **state) {
 	result = dst_lib_init(mctx, NULL);
 
 	if (result != ISC_R_SUCCESS) {
-		return (1);
+		return 1;
 	}
 
-	return (0);
+	return 0;
 }
 
 static int
@@ -92,7 +92,7 @@ teardown_test(void **state) {
 
 	dst_lib_destroy();
 
-	return (0);
+	return 0;
 }
 
 /*%
@@ -126,7 +126,8 @@ compare_tuples(const zonediff_t *expected, dns_difftuple_t *found,
 	 * Check owner name.
 	 */
 	expected_name = dns_fixedname_initname(&expected_fname);
-	result = dns_name_fromstring(expected_name, expected->owner, 0, mctx);
+	result = dns_name_fromstring(expected_name, expected->owner,
+				     dns_rootname, 0, mctx);
 	assert_int_equal(result, ISC_R_SUCCESS);
 	dns_name_format(&found->name, found_name, sizeof(found_name));
 	assert_true(dns_name_equal(expected_name, &found->name));
@@ -241,7 +242,7 @@ updatesigs_test(const updatesigs_test_params_t *test, dns_zone_t *zone,
 	 */
 	result = dns__zone_updatesigs(&raw_diff, db, version, zone_keys, nkeys,
 				      zone, now - 3600, now + 3600, 0, now,
-				      true, false, &zonediff);
+				      &zonediff);
 	assert_int_equal(result, ISC_R_SUCCESS);
 	assert_true(ISC_LIST_EMPTY(raw_diff.tuples));
 	assert_false(ISC_LIST_EMPTY(zone_diff.tuples));
@@ -292,7 +293,7 @@ ISC_RUN_TEST_IMPL(updatesigs_next) {
 	dns_db_t *db = NULL;
 	isc_result_t result;
 	unsigned int nkeys;
-	isc_stdtime_t now;
+	isc_stdtime_t now = isc_stdtime_now();
 	size_t i;
 
 	UNUSED(state);
@@ -311,9 +312,8 @@ ISC_RUN_TEST_IMPL(updatesigs_next) {
 	result = dns_zone_setkeydirectory(zone, TESTS_DIR "/testkeys");
 	assert_int_equal(result, ISC_R_SUCCESS);
 
-	isc_stdtime_get(&now);
-	result = dns__zone_findkeys(zone, db, NULL, now, mctx, DNS_MAXZONEKEYS,
-				    zone_keys, &nkeys);
+	result = dns_zone_findkeys(zone, db, NULL, now, mctx, DNS_MAXZONEKEYS,
+				   zone_keys, &nkeys);
 	assert_int_equal(result, ISC_R_SUCCESS);
 	assert_int_equal(nkeys, 2);
 
