@@ -470,7 +470,7 @@ ISC_RUN_TEST_IMPL(isc_mem_traceflag) {
 	assert_non_null(p);
 	p = strchr(p + 1, '\n');
 	assert_non_null(p);
-	assert_in_range(p, 0, buf + sizeof(buf) - 3);
+	assert_uint_in_range(p, 0, buf + sizeof(buf) - 3);
 	assert_memory_equal(p + 2, "ptr ", 4);
 	p = strchr(p + 1, '\n');
 	assert_non_null(p);
