@@ -177,8 +177,8 @@ qp_test_dumpmulti(dns_qpmulti_t *multi) {
 
 void
 qp_test_dumpchunks(dns_qp_t *qp) {
-	dns_qpcell_t used = 0;
-	dns_qpcell_t free = 0;
+	dns_qpcell_t used_count = 0;
+	dns_qpcell_t free_count = 0;
 	dumpqp(qp, "qp");
 	for (dns_qpchunk_t c = 0; c < qp->chunk_max; c++) {
 		printf("qp %p chunk %u base %p "
@@ -186,10 +186,11 @@ qp_test_dumpchunks(dns_qp_t *qp) {
 		       qp, c, qp->base->ptr[c], qp->usage[c].used,
 		       qp->usage[c].free, qp->usage[c].immutable,
 		       qp->usage[c].discounted);
-		used += qp->usage[c].used;
-		free += qp->usage[c].free;
+		used_count += qp->usage[c].used;
+		free_count += qp->usage[c].free;
 	}
-	printf("qp %p total used %u free %u\n", qp, used, free);
+	printf("qp %p total used %" PRIu32 " free %" PRIu32 "\n", qp,
+	       used_count, free_count);
 	fflush(stdout);
 }
 
